/* 
 * Figshare API
 *
 * Figshare apiv2. Using Swagger 2.0
 *
 * OpenAPI spec version: 2.0.0
 * 
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 */

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IArticlesApi : IApiAccessor
    {
        #region Synchronous Operations
        /// <summary>
        /// Account Article Report
        /// </summary>
        /// <remarks>
        /// Return status on all reports generated for the account from the oauth credentials
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="groupId">A group ID to filter by (optional)</param>
        /// <returns>List&lt;AccountReport&gt;</returns>
        List<AccountReport> AccountArticleReport (long? groupId = null);

        /// <summary>
        /// Account Article Report
        /// </summary>
        /// <remarks>
        /// Return status on all reports generated for the account from the oauth credentials
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="groupId">A group ID to filter by (optional)</param>
        /// <returns>ApiResponse of List&lt;AccountReport&gt;</returns>
        ApiResponse<List<AccountReport>> AccountArticleReportWithHttpInfo (long? groupId = null);
        /// <summary>
        /// Initiate a new Report
        /// </summary>
        /// <remarks>
        /// Initiate a new Article Report for this Account. There is a limit of 1 report per day.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>AccountReport</returns>
        AccountReport AccountArticleReportGenerate ();

        /// <summary>
        /// Initiate a new Report
        /// </summary>
        /// <remarks>
        /// Initiate a new Article Report for this Account. There is a limit of 1 report per day.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>ApiResponse of AccountReport</returns>
        ApiResponse<AccountReport> AccountArticleReportGenerateWithHttpInfo ();
        /// <summary>
        /// View article details
        /// </summary>
        /// <remarks>
        /// View an article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>ArticleComplete</returns>
        ArticleComplete ArticleDetails (long? articleId);

        /// <summary>
        /// View article details
        /// </summary>
        /// <remarks>
        /// View an article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>ApiResponse of ArticleComplete</returns>
        ApiResponse<ArticleComplete> ArticleDetailsWithHttpInfo (long? articleId);
        /// <summary>
        /// Article file details
        /// </summary>
        /// <remarks>
        /// File by id
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="fileId">File Unique identifier</param>
        /// <returns>PublicFile</returns>
        PublicFile ArticleFileDetails (long? articleId, long? fileId);

        /// <summary>
        /// Article file details
        /// </summary>
        /// <remarks>
        /// File by id
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="fileId">File Unique identifier</param>
        /// <returns>ApiResponse of PublicFile</returns>
        ApiResponse<PublicFile> ArticleFileDetailsWithHttpInfo (long? articleId, long? fileId);
        /// <summary>
        /// List article files
        /// </summary>
        /// <remarks>
        /// Files list for article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>List&lt;PublicFile&gt;</returns>
        List<PublicFile> ArticleFiles (long? articleId);

        /// <summary>
        /// List article files
        /// </summary>
        /// <remarks>
        /// Files list for article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>ApiResponse of List&lt;PublicFile&gt;</returns>
        ApiResponse<List<PublicFile>> ArticleFilesWithHttpInfo (long? articleId);
        /// <summary>
        /// Public Article Confidentiality for article version
        /// </summary>
        /// <remarks>
        /// Confidentiality for article version. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Version Number</param>
        /// <returns>ArticleConfidentiality</returns>
        ArticleConfidentiality ArticleVersionConfidentiality (long? articleId, long? vNumber);

        /// <summary>
        /// Public Article Confidentiality for article version
        /// </summary>
        /// <remarks>
        /// Confidentiality for article version. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Version Number</param>
        /// <returns>ApiResponse of ArticleConfidentiality</returns>
        ApiResponse<ArticleConfidentiality> ArticleVersionConfidentialityWithHttpInfo (long? articleId, long? vNumber);
        /// <summary>
        /// Article details for version
        /// </summary>
        /// <remarks>
        /// Article with specified version
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Article Version Number</param>
        /// <returns>ArticleComplete</returns>
        ArticleComplete ArticleVersionDetails (long? articleId, long? vNumber);

        /// <summary>
        /// Article details for version
        /// </summary>
        /// <remarks>
        /// Article with specified version
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Article Version Number</param>
        /// <returns>ApiResponse of ArticleComplete</returns>
        ApiResponse<ArticleComplete> ArticleVersionDetailsWithHttpInfo (long? articleId, long? vNumber);
        /// <summary>
        /// Public Article Embargo for article version
        /// </summary>
        /// <remarks>
        /// Embargo for article version
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Version Number</param>
        /// <returns>ArticleEmbargo</returns>
        ArticleEmbargo ArticleVersionEmbargo (long? articleId, long? vNumber);

        /// <summary>
        /// Public Article Embargo for article version
        /// </summary>
        /// <remarks>
        /// Embargo for article version
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Version Number</param>
        /// <returns>ApiResponse of ArticleEmbargo</returns>
        ApiResponse<ArticleEmbargo> ArticleVersionEmbargoWithHttpInfo (long? articleId, long? vNumber);
        /// <summary>
        /// Update article version
        /// </summary>
        /// <remarks>
        /// Updating an article version by passing body parameters; request can also be made with the PATCH method.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="versionId">Article version identifier</param>
        /// <param name="article">Article description</param>
        /// <returns>LocationWarningsUpdate</returns>
        LocationWarningsUpdate ArticleVersionUpdate (long? articleId, long? versionId, ArticleUpdate article);

        /// <summary>
        /// Update article version
        /// </summary>
        /// <remarks>
        /// Updating an article version by passing body parameters; request can also be made with the PATCH method.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="versionId">Article version identifier</param>
        /// <param name="article">Article description</param>
        /// <returns>ApiResponse of LocationWarningsUpdate</returns>
        ApiResponse<LocationWarningsUpdate> ArticleVersionUpdateWithHttpInfo (long? articleId, long? versionId, ArticleUpdate article);
        /// <summary>
        /// Update article version thumbnail
        /// </summary>
        /// <remarks>
        /// For a given public article version update the article thumbnail by choosing one of the associated files
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="versionId">Article version identifier</param>
        /// <param name="fileId">File ID</param>
        /// <returns></returns>
        void ArticleVersionUpdateThumb (long? articleId, long? versionId, FileId fileId);

        /// <summary>
        /// Update article version thumbnail
        /// </summary>
        /// <remarks>
        /// For a given public article version update the article thumbnail by choosing one of the associated files
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="versionId">Article version identifier</param>
        /// <param name="fileId">File ID</param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> ArticleVersionUpdateThumbWithHttpInfo (long? articleId, long? versionId, FileId fileId);
        /// <summary>
        /// List article versions
        /// </summary>
        /// <remarks>
        /// List public article versions
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>List&lt;ArticleVersions&gt;</returns>
        List<ArticleVersions> ArticleVersions (long? articleId);

        /// <summary>
        /// List article versions
        /// </summary>
        /// <remarks>
        /// List public article versions
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>ApiResponse of List&lt;ArticleVersions&gt;</returns>
        ApiResponse<List<ArticleVersions>> ArticleVersionsWithHttpInfo (long? articleId);
        /// <summary>
        /// Public Articles
        /// </summary>
        /// <remarks>
        /// Returns a list of public articles
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <param name="institution">only return articles from this institution (optional)</param>
        /// <param name="publishedSince">Filter by article publishing date. Will only return articles published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="modifiedSince">Filter by article modified date. Will only return articles published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="group">only return articles from this group (optional)</param>
        /// <param name="resourceDoi">only return articles with this resource_doi (optional)</param>
        /// <param name="itemType">Only return articles with the respective type. Mapping for item_type is: 1 - Figure, 2 - Media, 3 - Dataset, 5 - Poster, 6 - Journal contribution, 7 - Presentation, 8 - Thesis, 9 - Software, 11 - Online resource, 12 - Preprint, 13 - Book, 14 - Conference contribution, 15 - Chapter, 16 - Peer review, 17 - Educational resource, 18 - Report, 19 - Standard, 20 - Composition, 21 - Funding, 22 - Physical object, 23 - Data management plan, 24 - Workflow, 25 - Monograph, 26 - Performance, 27 - Event, 28 - Service, 29 - Model (optional)</param>
        /// <param name="doi">only return articles with this doi (optional)</param>
        /// <param name="handle">only return articles with this handle (optional)</param>
        /// <returns>List&lt;Article&gt;</returns>
        List<Article> ArticlesList (Guid? xCursor = null, long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null, long? institution = null, string publishedSince = null, string modifiedSince = null, long? group = null, string resourceDoi = null, long? itemType = null, string doi = null, string handle = null);

        /// <summary>
        /// Public Articles
        /// </summary>
        /// <remarks>
        /// Returns a list of public articles
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <param name="institution">only return articles from this institution (optional)</param>
        /// <param name="publishedSince">Filter by article publishing date. Will only return articles published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="modifiedSince">Filter by article modified date. Will only return articles published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="group">only return articles from this group (optional)</param>
        /// <param name="resourceDoi">only return articles with this resource_doi (optional)</param>
        /// <param name="itemType">Only return articles with the respective type. Mapping for item_type is: 1 - Figure, 2 - Media, 3 - Dataset, 5 - Poster, 6 - Journal contribution, 7 - Presentation, 8 - Thesis, 9 - Software, 11 - Online resource, 12 - Preprint, 13 - Book, 14 - Conference contribution, 15 - Chapter, 16 - Peer review, 17 - Educational resource, 18 - Report, 19 - Standard, 20 - Composition, 21 - Funding, 22 - Physical object, 23 - Data management plan, 24 - Workflow, 25 - Monograph, 26 - Performance, 27 - Event, 28 - Service, 29 - Model (optional)</param>
        /// <param name="doi">only return articles with this doi (optional)</param>
        /// <param name="handle">only return articles with this handle (optional)</param>
        /// <returns>ApiResponse of List&lt;Article&gt;</returns>
        ApiResponse<List<Article>> ArticlesListWithHttpInfo (Guid? xCursor = null, long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null, long? institution = null, string publishedSince = null, string modifiedSince = null, long? group = null, string resourceDoi = null, long? itemType = null, string doi = null, string handle = null);
        /// <summary>
        /// Public Articles Search
        /// </summary>
        /// <remarks>
        /// Returns a list of public articles, filtered by the search parameters
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="search">Search Parameters (optional)</param>
        /// <returns>List&lt;ArticleWithProject&gt;</returns>
        List<ArticleWithProject> ArticlesSearch (Guid? xCursor = null, ArticleSearch search = null);

        /// <summary>
        /// Public Articles Search
        /// </summary>
        /// <remarks>
        /// Returns a list of public articles, filtered by the search parameters
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="search">Search Parameters (optional)</param>
        /// <returns>ApiResponse of List&lt;ArticleWithProject&gt;</returns>
        ApiResponse<List<ArticleWithProject>> ArticlesSearchWithHttpInfo (Guid? xCursor = null, ArticleSearch search = null);
        /// <summary>
        /// Delete article author
        /// </summary>
        /// <remarks>
        /// De-associate author from article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authorId">Article Author unique identifier</param>
        /// <returns></returns>
        void PrivateArticleAuthorDelete (long? articleId, long? authorId);

        /// <summary>
        /// Delete article author
        /// </summary>
        /// <remarks>
        /// De-associate author from article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authorId">Article Author unique identifier</param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateArticleAuthorDeleteWithHttpInfo (long? articleId, long? authorId);
        /// <summary>
        /// Add article authors
        /// </summary>
        /// <remarks>
        /// Associate new authors with the article. This will add new authors to the list of already associated authors
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authors">Authors description</param>
        /// <returns></returns>
        void PrivateArticleAuthorsAdd (long? articleId, AuthorsCreator authors);

        /// <summary>
        /// Add article authors
        /// </summary>
        /// <remarks>
        /// Associate new authors with the article. This will add new authors to the list of already associated authors
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authors">Authors description</param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateArticleAuthorsAddWithHttpInfo (long? articleId, AuthorsCreator authors);
        /// <summary>
        /// List article authors
        /// </summary>
        /// <remarks>
        /// List article authors
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>List&lt;Author&gt;</returns>
        List<Author> PrivateArticleAuthorsList (long? articleId);

        /// <summary>
        /// List article authors
        /// </summary>
        /// <remarks>
        /// List article authors
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of List&lt;Author&gt;</returns>
        ApiResponse<List<Author>> PrivateArticleAuthorsListWithHttpInfo (long? articleId);
        /// <summary>
        /// Replace article authors
        /// </summary>
        /// <remarks>
        /// Associate new authors with the article. This will remove all already associated authors and add these new ones
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authors">Authors description</param>
        /// <returns></returns>
        void PrivateArticleAuthorsReplace (long? articleId, AuthorsCreator authors);

        /// <summary>
        /// Replace article authors
        /// </summary>
        /// <remarks>
        /// Associate new authors with the article. This will remove all already associated authors and add these new ones
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authors">Authors description</param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateArticleAuthorsReplaceWithHttpInfo (long? articleId, AuthorsCreator authors);
        /// <summary>
        /// Add article categories
        /// </summary>
        /// <remarks>
        /// Associate new categories with the article. This will add new categories to the list of already associated categories
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categories"></param>
        /// <returns></returns>
        void PrivateArticleCategoriesAdd (long? articleId, CategoriesCreator categories);

        /// <summary>
        /// Add article categories
        /// </summary>
        /// <remarks>
        /// Associate new categories with the article. This will add new categories to the list of already associated categories
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categories"></param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateArticleCategoriesAddWithHttpInfo (long? articleId, CategoriesCreator categories);
        /// <summary>
        /// List article categories
        /// </summary>
        /// <remarks>
        /// List article categories
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>List&lt;Category&gt;</returns>
        List<Category> PrivateArticleCategoriesList (long? articleId);

        /// <summary>
        /// List article categories
        /// </summary>
        /// <remarks>
        /// List article categories
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of List&lt;Category&gt;</returns>
        ApiResponse<List<Category>> PrivateArticleCategoriesListWithHttpInfo (long? articleId);
        /// <summary>
        /// Replace article categories
        /// </summary>
        /// <remarks>
        /// Associate new categories with the article. This will remove all already associated categories and add these new ones
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categories"></param>
        /// <returns></returns>
        void PrivateArticleCategoriesReplace (long? articleId, CategoriesCreator categories);

        /// <summary>
        /// Replace article categories
        /// </summary>
        /// <remarks>
        /// Associate new categories with the article. This will remove all already associated categories and add these new ones
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categories"></param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateArticleCategoriesReplaceWithHttpInfo (long? articleId, CategoriesCreator categories);
        /// <summary>
        /// Delete article category
        /// </summary>
        /// <remarks>
        /// De-associate category from article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categoryId">Category unique identifier</param>
        /// <returns></returns>
        void PrivateArticleCategoryDelete (long? articleId, long? categoryId);

        /// <summary>
        /// Delete article category
        /// </summary>
        /// <remarks>
        /// De-associate category from article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categoryId">Category unique identifier</param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateArticleCategoryDeleteWithHttpInfo (long? articleId, long? categoryId);
        /// <summary>
        /// Delete article confidentiality
        /// </summary>
        /// <remarks>
        /// Delete confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns></returns>
        void PrivateArticleConfidentialityDelete (long? articleId);

        /// <summary>
        /// Delete article confidentiality
        /// </summary>
        /// <remarks>
        /// Delete confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateArticleConfidentialityDeleteWithHttpInfo (long? articleId);
        /// <summary>
        /// Article confidentiality details
        /// </summary>
        /// <remarks>
        /// View confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ArticleConfidentiality</returns>
        ArticleConfidentiality PrivateArticleConfidentialityDetails (long? articleId);

        /// <summary>
        /// Article confidentiality details
        /// </summary>
        /// <remarks>
        /// View confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of ArticleConfidentiality</returns>
        ApiResponse<ArticleConfidentiality> PrivateArticleConfidentialityDetailsWithHttpInfo (long? articleId);
        /// <summary>
        /// Update article confidentiality
        /// </summary>
        /// <remarks>
        /// Update confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="reason"></param>
        /// <returns></returns>
        void PrivateArticleConfidentialityUpdate (long? articleId, ConfidentialityCreator reason);

        /// <summary>
        /// Update article confidentiality
        /// </summary>
        /// <remarks>
        /// Update confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="reason"></param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateArticleConfidentialityUpdateWithHttpInfo (long? articleId, ConfidentialityCreator reason);
        /// <summary>
        /// Create new Article
        /// </summary>
        /// <remarks>
        /// Create a new Article by sending article information
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="article">Article description</param>
        /// <returns>LocationWarnings</returns>
        LocationWarnings PrivateArticleCreate (ArticleCreate article);

        /// <summary>
        /// Create new Article
        /// </summary>
        /// <remarks>
        /// Create a new Article by sending article information
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="article">Article description</param>
        /// <returns>ApiResponse of LocationWarnings</returns>
        ApiResponse<LocationWarnings> PrivateArticleCreateWithHttpInfo (ArticleCreate article);
        /// <summary>
        /// Delete article
        /// </summary>
        /// <remarks>
        /// Delete an article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns></returns>
        void PrivateArticleDelete (long? articleId);

        /// <summary>
        /// Delete article
        /// </summary>
        /// <remarks>
        /// Delete an article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateArticleDeleteWithHttpInfo (long? articleId);
        /// <summary>
        /// Article details
        /// </summary>
        /// <remarks>
        /// View a private article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ArticleCompletePrivate</returns>
        ArticleCompletePrivate PrivateArticleDetails (long? articleId);

        /// <summary>
        /// Article details
        /// </summary>
        /// <remarks>
        /// View a private article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of ArticleCompletePrivate</returns>
        ApiResponse<ArticleCompletePrivate> PrivateArticleDetailsWithHttpInfo (long? articleId);
        /// <summary>
        /// Delete Article Embargo
        /// </summary>
        /// <remarks>
        /// Will lift the embargo for the specified article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns></returns>
        void PrivateArticleEmbargoDelete (long? articleId);

        /// <summary>
        /// Delete Article Embargo
        /// </summary>
        /// <remarks>
        /// Will lift the embargo for the specified article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateArticleEmbargoDeleteWithHttpInfo (long? articleId);
        /// <summary>
        /// Article Embargo Details
        /// </summary>
        /// <remarks>
        /// View a private article embargo details
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ArticleEmbargo</returns>
        ArticleEmbargo PrivateArticleEmbargoDetails (long? articleId);

        /// <summary>
        /// Article Embargo Details
        /// </summary>
        /// <remarks>
        /// View a private article embargo details
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of ArticleEmbargo</returns>
        ApiResponse<ArticleEmbargo> PrivateArticleEmbargoDetailsWithHttpInfo (long? articleId);
        /// <summary>
        /// Update Article Embargo
        /// </summary>
        /// <remarks>
        /// Note: setting an article under whole embargo does not imply that the article will be published when the embargo will expire. You must explicitly call the publish endpoint to enable this functionality.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="embargo">Embargo description</param>
        /// <returns></returns>
        void PrivateArticleEmbargoUpdate (long? articleId, ArticleEmbargoUpdater embargo);

        /// <summary>
        /// Update Article Embargo
        /// </summary>
        /// <remarks>
        /// Note: setting an article under whole embargo does not imply that the article will be published when the embargo will expire. You must explicitly call the publish endpoint to enable this functionality.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="embargo">Embargo description</param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateArticleEmbargoUpdateWithHttpInfo (long? articleId, ArticleEmbargoUpdater embargo);
        /// <summary>
        /// Single File
        /// </summary>
        /// <remarks>
        /// View details of file for specified article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns>PrivateFile</returns>
        PrivateFile PrivateArticleFile (long? articleId, long? fileId);

        /// <summary>
        /// Single File
        /// </summary>
        /// <remarks>
        /// View details of file for specified article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns>ApiResponse of PrivateFile</returns>
        ApiResponse<PrivateFile> PrivateArticleFileWithHttpInfo (long? articleId, long? fileId);
        /// <summary>
        /// File Delete
        /// </summary>
        /// <remarks>
        /// Complete file upload
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns></returns>
        void PrivateArticleFileDelete (long? articleId, long? fileId);

        /// <summary>
        /// File Delete
        /// </summary>
        /// <remarks>
        /// Complete file upload
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateArticleFileDeleteWithHttpInfo (long? articleId, long? fileId);
        /// <summary>
        /// List article files
        /// </summary>
        /// <remarks>
        /// List private files
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>List&lt;PrivateFile&gt;</returns>
        List<PrivateFile> PrivateArticleFilesList (long? articleId);

        /// <summary>
        /// List article files
        /// </summary>
        /// <remarks>
        /// List private files
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of List&lt;PrivateFile&gt;</returns>
        ApiResponse<List<PrivateFile>> PrivateArticleFilesListWithHttpInfo (long? articleId);
        /// <summary>
        /// List private links
        /// </summary>
        /// <remarks>
        /// List private links
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>List&lt;PrivateLink&gt;</returns>
        List<PrivateLink> PrivateArticlePrivateLink (long? articleId);

        /// <summary>
        /// List private links
        /// </summary>
        /// <remarks>
        /// List private links
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of List&lt;PrivateLink&gt;</returns>
        ApiResponse<List<PrivateLink>> PrivateArticlePrivateLinkWithHttpInfo (long? articleId);
        /// <summary>
        /// Create private link
        /// </summary>
        /// <remarks>
        /// Create new private link for this article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>PrivateLinkResponse</returns>
        PrivateLinkResponse PrivateArticlePrivateLinkCreate (long? articleId, PrivateLinkCreator privateLink = null);

        /// <summary>
        /// Create private link
        /// </summary>
        /// <remarks>
        /// Create new private link for this article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>ApiResponse of PrivateLinkResponse</returns>
        ApiResponse<PrivateLinkResponse> PrivateArticlePrivateLinkCreateWithHttpInfo (long? articleId, PrivateLinkCreator privateLink = null);
        /// <summary>
        /// Disable private link
        /// </summary>
        /// <remarks>
        /// Disable/delete private link for this article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <returns></returns>
        void PrivateArticlePrivateLinkDelete (long? articleId, string linkId);

        /// <summary>
        /// Disable private link
        /// </summary>
        /// <remarks>
        /// Disable/delete private link for this article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateArticlePrivateLinkDeleteWithHttpInfo (long? articleId, string linkId);
        /// <summary>
        /// Update private link
        /// </summary>
        /// <remarks>
        /// Update existing private link for this article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns></returns>
        void PrivateArticlePrivateLinkUpdate (long? articleId, string linkId, PrivateLinkCreator privateLink = null);

        /// <summary>
        /// Update private link
        /// </summary>
        /// <remarks>
        /// Update existing private link for this article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateArticlePrivateLinkUpdateWithHttpInfo (long? articleId, string linkId, PrivateLinkCreator privateLink = null);
        /// <summary>
        /// Private Article Publish
        /// </summary>
        /// <remarks>
        /// - If the whole article is under embargo, it will not be published immediately, but when the embargo expires or is lifted. - When an article is published, a new public version will be generated. Any further updates to the article will affect the private article data. In order to make these changes publicly visible, an explicit publish operation is needed.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Location</returns>
        Location PrivateArticlePublish (long? articleId);

        /// <summary>
        /// Private Article Publish
        /// </summary>
        /// <remarks>
        /// - If the whole article is under embargo, it will not be published immediately, but when the embargo expires or is lifted. - When an article is published, a new public version will be generated. Any further updates to the article will affect the private article data. In order to make these changes publicly visible, an explicit publish operation is needed.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of Location</returns>
        ApiResponse<Location> PrivateArticlePublishWithHttpInfo (long? articleId);
        /// <summary>
        /// Private Article Reserve DOI
        /// </summary>
        /// <remarks>
        /// Reserve DOI for article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ArticleDOI</returns>
        ArticleDOI PrivateArticleReserveDoi (long? articleId);

        /// <summary>
        /// Private Article Reserve DOI
        /// </summary>
        /// <remarks>
        /// Reserve DOI for article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of ArticleDOI</returns>
        ApiResponse<ArticleDOI> PrivateArticleReserveDoiWithHttpInfo (long? articleId);
        /// <summary>
        /// Private Article Reserve Handle
        /// </summary>
        /// <remarks>
        /// Reserve Handle for article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ArticleHandle</returns>
        ArticleHandle PrivateArticleReserveHandle (long? articleId);

        /// <summary>
        /// Private Article Reserve Handle
        /// </summary>
        /// <remarks>
        /// Reserve Handle for article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of ArticleHandle</returns>
        ApiResponse<ArticleHandle> PrivateArticleReserveHandleWithHttpInfo (long? articleId);
        /// <summary>
        /// Private Article Resource
        /// </summary>
        /// <remarks>
        /// Edit article resource data.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="resource">Resource data</param>
        /// <returns>Location</returns>
        Location PrivateArticleResource (long? articleId, Resource resource);

        /// <summary>
        /// Private Article Resource
        /// </summary>
        /// <remarks>
        /// Edit article resource data.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="resource">Resource data</param>
        /// <returns>ApiResponse of Location</returns>
        ApiResponse<Location> PrivateArticleResourceWithHttpInfo (long? articleId, Resource resource);
        /// <summary>
        /// Update article
        /// </summary>
        /// <remarks>
        /// Updating an article by passing body parameters; request can also be made with the PATCH method.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="article">Article description</param>
        /// <returns>LocationWarningsUpdate</returns>
        LocationWarningsUpdate PrivateArticleUpdate (long? articleId, ArticleUpdate article);

        /// <summary>
        /// Update article
        /// </summary>
        /// <remarks>
        /// Updating an article by passing body parameters; request can also be made with the PATCH method.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="article">Article description</param>
        /// <returns>ApiResponse of LocationWarningsUpdate</returns>
        ApiResponse<LocationWarningsUpdate> PrivateArticleUpdateWithHttpInfo (long? articleId, ArticleUpdate article);
        /// <summary>
        /// Complete Upload
        /// </summary>
        /// <remarks>
        /// Complete file upload
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns></returns>
        void PrivateArticleUploadComplete (long? articleId, long? fileId);

        /// <summary>
        /// Complete Upload
        /// </summary>
        /// <remarks>
        /// Complete file upload
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns>ApiResponse of Object(void)</returns>
        ApiResponse<Object> PrivateArticleUploadCompleteWithHttpInfo (long? articleId, long? fileId);
        /// <summary>
        /// Initiate Upload
        /// </summary>
        /// <remarks>
        /// Initiate a new file upload within the article. Either use the link property to point to an existing file that resides elsewhere and will not be uploaded to Figshare or use the other 3 parameters (md5, name, size).
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="_file"></param>
        /// <returns>Location</returns>
        Location PrivateArticleUploadInitiate (long? articleId, FileCreator _file);

        /// <summary>
        /// Initiate Upload
        /// </summary>
        /// <remarks>
        /// Initiate a new file upload within the article. Either use the link property to point to an existing file that resides elsewhere and will not be uploaded to Figshare or use the other 3 parameters (md5, name, size).
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="_file"></param>
        /// <returns>ApiResponse of Location</returns>
        ApiResponse<Location> PrivateArticleUploadInitiateWithHttpInfo (long? articleId, FileCreator _file);
        /// <summary>
        /// Private Articles
        /// </summary>
        /// <remarks>
        /// Get Own Articles
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>List&lt;Article&gt;</returns>
        List<Article> PrivateArticlesList (long? page = null, long? pageSize = null, long? limit = null, long? offset = null);

        /// <summary>
        /// Private Articles
        /// </summary>
        /// <remarks>
        /// Get Own Articles
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>ApiResponse of List&lt;Article&gt;</returns>
        ApiResponse<List<Article>> PrivateArticlesListWithHttpInfo (long? page = null, long? pageSize = null, long? limit = null, long? offset = null);
        /// <summary>
        /// Private Articles search
        /// </summary>
        /// <remarks>
        /// Returns a list of private articles filtered by the search parameters
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="search">Search Parameters</param>
        /// <returns>List&lt;ArticleWithProject&gt;</returns>
        List<ArticleWithProject> PrivateArticlesSearch (PrivateArticleSearch search);

        /// <summary>
        /// Private Articles search
        /// </summary>
        /// <remarks>
        /// Returns a list of private articles filtered by the search parameters
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="search">Search Parameters</param>
        /// <returns>ApiResponse of List&lt;ArticleWithProject&gt;</returns>
        ApiResponse<List<ArticleWithProject>> PrivateArticlesSearchWithHttpInfo (PrivateArticleSearch search);
        #endregion Synchronous Operations
        #region Asynchronous Operations
        /// <summary>
        /// Account Article Report
        /// </summary>
        /// <remarks>
        /// Return status on all reports generated for the account from the oauth credentials
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="groupId">A group ID to filter by (optional)</param>
        /// <returns>Task of List&lt;AccountReport&gt;</returns>
        System.Threading.Tasks.Task<List<AccountReport>> AccountArticleReportAsync (long? groupId = null);

        /// <summary>
        /// Account Article Report
        /// </summary>
        /// <remarks>
        /// Return status on all reports generated for the account from the oauth credentials
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="groupId">A group ID to filter by (optional)</param>
        /// <returns>Task of ApiResponse (List&lt;AccountReport&gt;)</returns>
        System.Threading.Tasks.Task<ApiResponse<List<AccountReport>>> AccountArticleReportAsyncWithHttpInfo (long? groupId = null);
        /// <summary>
        /// Initiate a new Report
        /// </summary>
        /// <remarks>
        /// Initiate a new Article Report for this Account. There is a limit of 1 report per day.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>Task of AccountReport</returns>
        System.Threading.Tasks.Task<AccountReport> AccountArticleReportGenerateAsync ();

        /// <summary>
        /// Initiate a new Report
        /// </summary>
        /// <remarks>
        /// Initiate a new Article Report for this Account. There is a limit of 1 report per day.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>Task of ApiResponse (AccountReport)</returns>
        System.Threading.Tasks.Task<ApiResponse<AccountReport>> AccountArticleReportGenerateAsyncWithHttpInfo ();
        /// <summary>
        /// View article details
        /// </summary>
        /// <remarks>
        /// View an article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>Task of ArticleComplete</returns>
        System.Threading.Tasks.Task<ArticleComplete> ArticleDetailsAsync (long? articleId);

        /// <summary>
        /// View article details
        /// </summary>
        /// <remarks>
        /// View an article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>Task of ApiResponse (ArticleComplete)</returns>
        System.Threading.Tasks.Task<ApiResponse<ArticleComplete>> ArticleDetailsAsyncWithHttpInfo (long? articleId);
        /// <summary>
        /// Article file details
        /// </summary>
        /// <remarks>
        /// File by id
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="fileId">File Unique identifier</param>
        /// <returns>Task of PublicFile</returns>
        System.Threading.Tasks.Task<PublicFile> ArticleFileDetailsAsync (long? articleId, long? fileId);

        /// <summary>
        /// Article file details
        /// </summary>
        /// <remarks>
        /// File by id
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="fileId">File Unique identifier</param>
        /// <returns>Task of ApiResponse (PublicFile)</returns>
        System.Threading.Tasks.Task<ApiResponse<PublicFile>> ArticleFileDetailsAsyncWithHttpInfo (long? articleId, long? fileId);
        /// <summary>
        /// List article files
        /// </summary>
        /// <remarks>
        /// Files list for article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>Task of List&lt;PublicFile&gt;</returns>
        System.Threading.Tasks.Task<List<PublicFile>> ArticleFilesAsync (long? articleId);

        /// <summary>
        /// List article files
        /// </summary>
        /// <remarks>
        /// Files list for article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>Task of ApiResponse (List&lt;PublicFile&gt;)</returns>
        System.Threading.Tasks.Task<ApiResponse<List<PublicFile>>> ArticleFilesAsyncWithHttpInfo (long? articleId);
        /// <summary>
        /// Public Article Confidentiality for article version
        /// </summary>
        /// <remarks>
        /// Confidentiality for article version. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Version Number</param>
        /// <returns>Task of ArticleConfidentiality</returns>
        System.Threading.Tasks.Task<ArticleConfidentiality> ArticleVersionConfidentialityAsync (long? articleId, long? vNumber);

        /// <summary>
        /// Public Article Confidentiality for article version
        /// </summary>
        /// <remarks>
        /// Confidentiality for article version. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Version Number</param>
        /// <returns>Task of ApiResponse (ArticleConfidentiality)</returns>
        System.Threading.Tasks.Task<ApiResponse<ArticleConfidentiality>> ArticleVersionConfidentialityAsyncWithHttpInfo (long? articleId, long? vNumber);
        /// <summary>
        /// Article details for version
        /// </summary>
        /// <remarks>
        /// Article with specified version
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Article Version Number</param>
        /// <returns>Task of ArticleComplete</returns>
        System.Threading.Tasks.Task<ArticleComplete> ArticleVersionDetailsAsync (long? articleId, long? vNumber);

        /// <summary>
        /// Article details for version
        /// </summary>
        /// <remarks>
        /// Article with specified version
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Article Version Number</param>
        /// <returns>Task of ApiResponse (ArticleComplete)</returns>
        System.Threading.Tasks.Task<ApiResponse<ArticleComplete>> ArticleVersionDetailsAsyncWithHttpInfo (long? articleId, long? vNumber);
        /// <summary>
        /// Public Article Embargo for article version
        /// </summary>
        /// <remarks>
        /// Embargo for article version
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Version Number</param>
        /// <returns>Task of ArticleEmbargo</returns>
        System.Threading.Tasks.Task<ArticleEmbargo> ArticleVersionEmbargoAsync (long? articleId, long? vNumber);

        /// <summary>
        /// Public Article Embargo for article version
        /// </summary>
        /// <remarks>
        /// Embargo for article version
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Version Number</param>
        /// <returns>Task of ApiResponse (ArticleEmbargo)</returns>
        System.Threading.Tasks.Task<ApiResponse<ArticleEmbargo>> ArticleVersionEmbargoAsyncWithHttpInfo (long? articleId, long? vNumber);
        /// <summary>
        /// Update article version
        /// </summary>
        /// <remarks>
        /// Updating an article version by passing body parameters; request can also be made with the PATCH method.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="versionId">Article version identifier</param>
        /// <param name="article">Article description</param>
        /// <returns>Task of LocationWarningsUpdate</returns>
        System.Threading.Tasks.Task<LocationWarningsUpdate> ArticleVersionUpdateAsync (long? articleId, long? versionId, ArticleUpdate article);

        /// <summary>
        /// Update article version
        /// </summary>
        /// <remarks>
        /// Updating an article version by passing body parameters; request can also be made with the PATCH method.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="versionId">Article version identifier</param>
        /// <param name="article">Article description</param>
        /// <returns>Task of ApiResponse (LocationWarningsUpdate)</returns>
        System.Threading.Tasks.Task<ApiResponse<LocationWarningsUpdate>> ArticleVersionUpdateAsyncWithHttpInfo (long? articleId, long? versionId, ArticleUpdate article);
        /// <summary>
        /// Update article version thumbnail
        /// </summary>
        /// <remarks>
        /// For a given public article version update the article thumbnail by choosing one of the associated files
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="versionId">Article version identifier</param>
        /// <param name="fileId">File ID</param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task ArticleVersionUpdateThumbAsync (long? articleId, long? versionId, FileId fileId);

        /// <summary>
        /// Update article version thumbnail
        /// </summary>
        /// <remarks>
        /// For a given public article version update the article thumbnail by choosing one of the associated files
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="versionId">Article version identifier</param>
        /// <param name="fileId">File ID</param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> ArticleVersionUpdateThumbAsyncWithHttpInfo (long? articleId, long? versionId, FileId fileId);
        /// <summary>
        /// List article versions
        /// </summary>
        /// <remarks>
        /// List public article versions
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>Task of List&lt;ArticleVersions&gt;</returns>
        System.Threading.Tasks.Task<List<ArticleVersions>> ArticleVersionsAsync (long? articleId);

        /// <summary>
        /// List article versions
        /// </summary>
        /// <remarks>
        /// List public article versions
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>Task of ApiResponse (List&lt;ArticleVersions&gt;)</returns>
        System.Threading.Tasks.Task<ApiResponse<List<ArticleVersions>>> ArticleVersionsAsyncWithHttpInfo (long? articleId);
        /// <summary>
        /// Public Articles
        /// </summary>
        /// <remarks>
        /// Returns a list of public articles
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <param name="institution">only return articles from this institution (optional)</param>
        /// <param name="publishedSince">Filter by article publishing date. Will only return articles published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="modifiedSince">Filter by article modified date. Will only return articles published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="group">only return articles from this group (optional)</param>
        /// <param name="resourceDoi">only return articles with this resource_doi (optional)</param>
        /// <param name="itemType">Only return articles with the respective type. Mapping for item_type is: 1 - Figure, 2 - Media, 3 - Dataset, 5 - Poster, 6 - Journal contribution, 7 - Presentation, 8 - Thesis, 9 - Software, 11 - Online resource, 12 - Preprint, 13 - Book, 14 - Conference contribution, 15 - Chapter, 16 - Peer review, 17 - Educational resource, 18 - Report, 19 - Standard, 20 - Composition, 21 - Funding, 22 - Physical object, 23 - Data management plan, 24 - Workflow, 25 - Monograph, 26 - Performance, 27 - Event, 28 - Service, 29 - Model (optional)</param>
        /// <param name="doi">only return articles with this doi (optional)</param>
        /// <param name="handle">only return articles with this handle (optional)</param>
        /// <returns>Task of List&lt;Article&gt;</returns>
        System.Threading.Tasks.Task<List<Article>> ArticlesListAsync (Guid? xCursor = null, long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null, long? institution = null, string publishedSince = null, string modifiedSince = null, long? group = null, string resourceDoi = null, long? itemType = null, string doi = null, string handle = null);

        /// <summary>
        /// Public Articles
        /// </summary>
        /// <remarks>
        /// Returns a list of public articles
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <param name="institution">only return articles from this institution (optional)</param>
        /// <param name="publishedSince">Filter by article publishing date. Will only return articles published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="modifiedSince">Filter by article modified date. Will only return articles published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="group">only return articles from this group (optional)</param>
        /// <param name="resourceDoi">only return articles with this resource_doi (optional)</param>
        /// <param name="itemType">Only return articles with the respective type. Mapping for item_type is: 1 - Figure, 2 - Media, 3 - Dataset, 5 - Poster, 6 - Journal contribution, 7 - Presentation, 8 - Thesis, 9 - Software, 11 - Online resource, 12 - Preprint, 13 - Book, 14 - Conference contribution, 15 - Chapter, 16 - Peer review, 17 - Educational resource, 18 - Report, 19 - Standard, 20 - Composition, 21 - Funding, 22 - Physical object, 23 - Data management plan, 24 - Workflow, 25 - Monograph, 26 - Performance, 27 - Event, 28 - Service, 29 - Model (optional)</param>
        /// <param name="doi">only return articles with this doi (optional)</param>
        /// <param name="handle">only return articles with this handle (optional)</param>
        /// <returns>Task of ApiResponse (List&lt;Article&gt;)</returns>
        System.Threading.Tasks.Task<ApiResponse<List<Article>>> ArticlesListAsyncWithHttpInfo (Guid? xCursor = null, long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null, long? institution = null, string publishedSince = null, string modifiedSince = null, long? group = null, string resourceDoi = null, long? itemType = null, string doi = null, string handle = null);
        /// <summary>
        /// Public Articles Search
        /// </summary>
        /// <remarks>
        /// Returns a list of public articles, filtered by the search parameters
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="search">Search Parameters (optional)</param>
        /// <returns>Task of List&lt;ArticleWithProject&gt;</returns>
        System.Threading.Tasks.Task<List<ArticleWithProject>> ArticlesSearchAsync (Guid? xCursor = null, ArticleSearch search = null);

        /// <summary>
        /// Public Articles Search
        /// </summary>
        /// <remarks>
        /// Returns a list of public articles, filtered by the search parameters
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="search">Search Parameters (optional)</param>
        /// <returns>Task of ApiResponse (List&lt;ArticleWithProject&gt;)</returns>
        System.Threading.Tasks.Task<ApiResponse<List<ArticleWithProject>>> ArticlesSearchAsyncWithHttpInfo (Guid? xCursor = null, ArticleSearch search = null);
        /// <summary>
        /// Delete article author
        /// </summary>
        /// <remarks>
        /// De-associate author from article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authorId">Article Author unique identifier</param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateArticleAuthorDeleteAsync (long? articleId, long? authorId);

        /// <summary>
        /// Delete article author
        /// </summary>
        /// <remarks>
        /// De-associate author from article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authorId">Article Author unique identifier</param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleAuthorDeleteAsyncWithHttpInfo (long? articleId, long? authorId);
        /// <summary>
        /// Add article authors
        /// </summary>
        /// <remarks>
        /// Associate new authors with the article. This will add new authors to the list of already associated authors
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authors">Authors description</param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateArticleAuthorsAddAsync (long? articleId, AuthorsCreator authors);

        /// <summary>
        /// Add article authors
        /// </summary>
        /// <remarks>
        /// Associate new authors with the article. This will add new authors to the list of already associated authors
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authors">Authors description</param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleAuthorsAddAsyncWithHttpInfo (long? articleId, AuthorsCreator authors);
        /// <summary>
        /// List article authors
        /// </summary>
        /// <remarks>
        /// List article authors
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of List&lt;Author&gt;</returns>
        System.Threading.Tasks.Task<List<Author>> PrivateArticleAuthorsListAsync (long? articleId);

        /// <summary>
        /// List article authors
        /// </summary>
        /// <remarks>
        /// List article authors
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse (List&lt;Author&gt;)</returns>
        System.Threading.Tasks.Task<ApiResponse<List<Author>>> PrivateArticleAuthorsListAsyncWithHttpInfo (long? articleId);
        /// <summary>
        /// Replace article authors
        /// </summary>
        /// <remarks>
        /// Associate new authors with the article. This will remove all already associated authors and add these new ones
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authors">Authors description</param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateArticleAuthorsReplaceAsync (long? articleId, AuthorsCreator authors);

        /// <summary>
        /// Replace article authors
        /// </summary>
        /// <remarks>
        /// Associate new authors with the article. This will remove all already associated authors and add these new ones
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authors">Authors description</param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleAuthorsReplaceAsyncWithHttpInfo (long? articleId, AuthorsCreator authors);
        /// <summary>
        /// Add article categories
        /// </summary>
        /// <remarks>
        /// Associate new categories with the article. This will add new categories to the list of already associated categories
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categories"></param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateArticleCategoriesAddAsync (long? articleId, CategoriesCreator categories);

        /// <summary>
        /// Add article categories
        /// </summary>
        /// <remarks>
        /// Associate new categories with the article. This will add new categories to the list of already associated categories
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categories"></param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleCategoriesAddAsyncWithHttpInfo (long? articleId, CategoriesCreator categories);
        /// <summary>
        /// List article categories
        /// </summary>
        /// <remarks>
        /// List article categories
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of List&lt;Category&gt;</returns>
        System.Threading.Tasks.Task<List<Category>> PrivateArticleCategoriesListAsync (long? articleId);

        /// <summary>
        /// List article categories
        /// </summary>
        /// <remarks>
        /// List article categories
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse (List&lt;Category&gt;)</returns>
        System.Threading.Tasks.Task<ApiResponse<List<Category>>> PrivateArticleCategoriesListAsyncWithHttpInfo (long? articleId);
        /// <summary>
        /// Replace article categories
        /// </summary>
        /// <remarks>
        /// Associate new categories with the article. This will remove all already associated categories and add these new ones
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categories"></param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateArticleCategoriesReplaceAsync (long? articleId, CategoriesCreator categories);

        /// <summary>
        /// Replace article categories
        /// </summary>
        /// <remarks>
        /// Associate new categories with the article. This will remove all already associated categories and add these new ones
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categories"></param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleCategoriesReplaceAsyncWithHttpInfo (long? articleId, CategoriesCreator categories);
        /// <summary>
        /// Delete article category
        /// </summary>
        /// <remarks>
        /// De-associate category from article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categoryId">Category unique identifier</param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateArticleCategoryDeleteAsync (long? articleId, long? categoryId);

        /// <summary>
        /// Delete article category
        /// </summary>
        /// <remarks>
        /// De-associate category from article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categoryId">Category unique identifier</param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleCategoryDeleteAsyncWithHttpInfo (long? articleId, long? categoryId);
        /// <summary>
        /// Delete article confidentiality
        /// </summary>
        /// <remarks>
        /// Delete confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateArticleConfidentialityDeleteAsync (long? articleId);

        /// <summary>
        /// Delete article confidentiality
        /// </summary>
        /// <remarks>
        /// Delete confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleConfidentialityDeleteAsyncWithHttpInfo (long? articleId);
        /// <summary>
        /// Article confidentiality details
        /// </summary>
        /// <remarks>
        /// View confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ArticleConfidentiality</returns>
        System.Threading.Tasks.Task<ArticleConfidentiality> PrivateArticleConfidentialityDetailsAsync (long? articleId);

        /// <summary>
        /// Article confidentiality details
        /// </summary>
        /// <remarks>
        /// View confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse (ArticleConfidentiality)</returns>
        System.Threading.Tasks.Task<ApiResponse<ArticleConfidentiality>> PrivateArticleConfidentialityDetailsAsyncWithHttpInfo (long? articleId);
        /// <summary>
        /// Update article confidentiality
        /// </summary>
        /// <remarks>
        /// Update confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="reason"></param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateArticleConfidentialityUpdateAsync (long? articleId, ConfidentialityCreator reason);

        /// <summary>
        /// Update article confidentiality
        /// </summary>
        /// <remarks>
        /// Update confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="reason"></param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleConfidentialityUpdateAsyncWithHttpInfo (long? articleId, ConfidentialityCreator reason);
        /// <summary>
        /// Create new Article
        /// </summary>
        /// <remarks>
        /// Create a new Article by sending article information
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="article">Article description</param>
        /// <returns>Task of LocationWarnings</returns>
        System.Threading.Tasks.Task<LocationWarnings> PrivateArticleCreateAsync (ArticleCreate article);

        /// <summary>
        /// Create new Article
        /// </summary>
        /// <remarks>
        /// Create a new Article by sending article information
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="article">Article description</param>
        /// <returns>Task of ApiResponse (LocationWarnings)</returns>
        System.Threading.Tasks.Task<ApiResponse<LocationWarnings>> PrivateArticleCreateAsyncWithHttpInfo (ArticleCreate article);
        /// <summary>
        /// Delete article
        /// </summary>
        /// <remarks>
        /// Delete an article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateArticleDeleteAsync (long? articleId);

        /// <summary>
        /// Delete article
        /// </summary>
        /// <remarks>
        /// Delete an article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleDeleteAsyncWithHttpInfo (long? articleId);
        /// <summary>
        /// Article details
        /// </summary>
        /// <remarks>
        /// View a private article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ArticleCompletePrivate</returns>
        System.Threading.Tasks.Task<ArticleCompletePrivate> PrivateArticleDetailsAsync (long? articleId);

        /// <summary>
        /// Article details
        /// </summary>
        /// <remarks>
        /// View a private article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse (ArticleCompletePrivate)</returns>
        System.Threading.Tasks.Task<ApiResponse<ArticleCompletePrivate>> PrivateArticleDetailsAsyncWithHttpInfo (long? articleId);
        /// <summary>
        /// Delete Article Embargo
        /// </summary>
        /// <remarks>
        /// Will lift the embargo for the specified article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateArticleEmbargoDeleteAsync (long? articleId);

        /// <summary>
        /// Delete Article Embargo
        /// </summary>
        /// <remarks>
        /// Will lift the embargo for the specified article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleEmbargoDeleteAsyncWithHttpInfo (long? articleId);
        /// <summary>
        /// Article Embargo Details
        /// </summary>
        /// <remarks>
        /// View a private article embargo details
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ArticleEmbargo</returns>
        System.Threading.Tasks.Task<ArticleEmbargo> PrivateArticleEmbargoDetailsAsync (long? articleId);

        /// <summary>
        /// Article Embargo Details
        /// </summary>
        /// <remarks>
        /// View a private article embargo details
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse (ArticleEmbargo)</returns>
        System.Threading.Tasks.Task<ApiResponse<ArticleEmbargo>> PrivateArticleEmbargoDetailsAsyncWithHttpInfo (long? articleId);
        /// <summary>
        /// Update Article Embargo
        /// </summary>
        /// <remarks>
        /// Note: setting an article under whole embargo does not imply that the article will be published when the embargo will expire. You must explicitly call the publish endpoint to enable this functionality.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="embargo">Embargo description</param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateArticleEmbargoUpdateAsync (long? articleId, ArticleEmbargoUpdater embargo);

        /// <summary>
        /// Update Article Embargo
        /// </summary>
        /// <remarks>
        /// Note: setting an article under whole embargo does not imply that the article will be published when the embargo will expire. You must explicitly call the publish endpoint to enable this functionality.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="embargo">Embargo description</param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleEmbargoUpdateAsyncWithHttpInfo (long? articleId, ArticleEmbargoUpdater embargo);
        /// <summary>
        /// Single File
        /// </summary>
        /// <remarks>
        /// View details of file for specified article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns>Task of PrivateFile</returns>
        System.Threading.Tasks.Task<PrivateFile> PrivateArticleFileAsync (long? articleId, long? fileId);

        /// <summary>
        /// Single File
        /// </summary>
        /// <remarks>
        /// View details of file for specified article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns>Task of ApiResponse (PrivateFile)</returns>
        System.Threading.Tasks.Task<ApiResponse<PrivateFile>> PrivateArticleFileAsyncWithHttpInfo (long? articleId, long? fileId);
        /// <summary>
        /// File Delete
        /// </summary>
        /// <remarks>
        /// Complete file upload
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateArticleFileDeleteAsync (long? articleId, long? fileId);

        /// <summary>
        /// File Delete
        /// </summary>
        /// <remarks>
        /// Complete file upload
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleFileDeleteAsyncWithHttpInfo (long? articleId, long? fileId);
        /// <summary>
        /// List article files
        /// </summary>
        /// <remarks>
        /// List private files
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of List&lt;PrivateFile&gt;</returns>
        System.Threading.Tasks.Task<List<PrivateFile>> PrivateArticleFilesListAsync (long? articleId);

        /// <summary>
        /// List article files
        /// </summary>
        /// <remarks>
        /// List private files
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse (List&lt;PrivateFile&gt;)</returns>
        System.Threading.Tasks.Task<ApiResponse<List<PrivateFile>>> PrivateArticleFilesListAsyncWithHttpInfo (long? articleId);
        /// <summary>
        /// List private links
        /// </summary>
        /// <remarks>
        /// List private links
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of List&lt;PrivateLink&gt;</returns>
        System.Threading.Tasks.Task<List<PrivateLink>> PrivateArticlePrivateLinkAsync (long? articleId);

        /// <summary>
        /// List private links
        /// </summary>
        /// <remarks>
        /// List private links
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse (List&lt;PrivateLink&gt;)</returns>
        System.Threading.Tasks.Task<ApiResponse<List<PrivateLink>>> PrivateArticlePrivateLinkAsyncWithHttpInfo (long? articleId);
        /// <summary>
        /// Create private link
        /// </summary>
        /// <remarks>
        /// Create new private link for this article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>Task of PrivateLinkResponse</returns>
        System.Threading.Tasks.Task<PrivateLinkResponse> PrivateArticlePrivateLinkCreateAsync (long? articleId, PrivateLinkCreator privateLink = null);

        /// <summary>
        /// Create private link
        /// </summary>
        /// <remarks>
        /// Create new private link for this article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>Task of ApiResponse (PrivateLinkResponse)</returns>
        System.Threading.Tasks.Task<ApiResponse<PrivateLinkResponse>> PrivateArticlePrivateLinkCreateAsyncWithHttpInfo (long? articleId, PrivateLinkCreator privateLink = null);
        /// <summary>
        /// Disable private link
        /// </summary>
        /// <remarks>
        /// Disable/delete private link for this article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateArticlePrivateLinkDeleteAsync (long? articleId, string linkId);

        /// <summary>
        /// Disable private link
        /// </summary>
        /// <remarks>
        /// Disable/delete private link for this article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticlePrivateLinkDeleteAsyncWithHttpInfo (long? articleId, string linkId);
        /// <summary>
        /// Update private link
        /// </summary>
        /// <remarks>
        /// Update existing private link for this article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateArticlePrivateLinkUpdateAsync (long? articleId, string linkId, PrivateLinkCreator privateLink = null);

        /// <summary>
        /// Update private link
        /// </summary>
        /// <remarks>
        /// Update existing private link for this article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticlePrivateLinkUpdateAsyncWithHttpInfo (long? articleId, string linkId, PrivateLinkCreator privateLink = null);
        /// <summary>
        /// Private Article Publish
        /// </summary>
        /// <remarks>
        /// - If the whole article is under embargo, it will not be published immediately, but when the embargo expires or is lifted. - When an article is published, a new public version will be generated. Any further updates to the article will affect the private article data. In order to make these changes publicly visible, an explicit publish operation is needed.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of Location</returns>
        System.Threading.Tasks.Task<Location> PrivateArticlePublishAsync (long? articleId);

        /// <summary>
        /// Private Article Publish
        /// </summary>
        /// <remarks>
        /// - If the whole article is under embargo, it will not be published immediately, but when the embargo expires or is lifted. - When an article is published, a new public version will be generated. Any further updates to the article will affect the private article data. In order to make these changes publicly visible, an explicit publish operation is needed.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse (Location)</returns>
        System.Threading.Tasks.Task<ApiResponse<Location>> PrivateArticlePublishAsyncWithHttpInfo (long? articleId);
        /// <summary>
        /// Private Article Reserve DOI
        /// </summary>
        /// <remarks>
        /// Reserve DOI for article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ArticleDOI</returns>
        System.Threading.Tasks.Task<ArticleDOI> PrivateArticleReserveDoiAsync (long? articleId);

        /// <summary>
        /// Private Article Reserve DOI
        /// </summary>
        /// <remarks>
        /// Reserve DOI for article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse (ArticleDOI)</returns>
        System.Threading.Tasks.Task<ApiResponse<ArticleDOI>> PrivateArticleReserveDoiAsyncWithHttpInfo (long? articleId);
        /// <summary>
        /// Private Article Reserve Handle
        /// </summary>
        /// <remarks>
        /// Reserve Handle for article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ArticleHandle</returns>
        System.Threading.Tasks.Task<ArticleHandle> PrivateArticleReserveHandleAsync (long? articleId);

        /// <summary>
        /// Private Article Reserve Handle
        /// </summary>
        /// <remarks>
        /// Reserve Handle for article
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse (ArticleHandle)</returns>
        System.Threading.Tasks.Task<ApiResponse<ArticleHandle>> PrivateArticleReserveHandleAsyncWithHttpInfo (long? articleId);
        /// <summary>
        /// Private Article Resource
        /// </summary>
        /// <remarks>
        /// Edit article resource data.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="resource">Resource data</param>
        /// <returns>Task of Location</returns>
        System.Threading.Tasks.Task<Location> PrivateArticleResourceAsync (long? articleId, Resource resource);

        /// <summary>
        /// Private Article Resource
        /// </summary>
        /// <remarks>
        /// Edit article resource data.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="resource">Resource data</param>
        /// <returns>Task of ApiResponse (Location)</returns>
        System.Threading.Tasks.Task<ApiResponse<Location>> PrivateArticleResourceAsyncWithHttpInfo (long? articleId, Resource resource);
        /// <summary>
        /// Update article
        /// </summary>
        /// <remarks>
        /// Updating an article by passing body parameters; request can also be made with the PATCH method.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="article">Article description</param>
        /// <returns>Task of LocationWarningsUpdate</returns>
        System.Threading.Tasks.Task<LocationWarningsUpdate> PrivateArticleUpdateAsync (long? articleId, ArticleUpdate article);

        /// <summary>
        /// Update article
        /// </summary>
        /// <remarks>
        /// Updating an article by passing body parameters; request can also be made with the PATCH method.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="article">Article description</param>
        /// <returns>Task of ApiResponse (LocationWarningsUpdate)</returns>
        System.Threading.Tasks.Task<ApiResponse<LocationWarningsUpdate>> PrivateArticleUpdateAsyncWithHttpInfo (long? articleId, ArticleUpdate article);
        /// <summary>
        /// Complete Upload
        /// </summary>
        /// <remarks>
        /// Complete file upload
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns>Task of void</returns>
        System.Threading.Tasks.Task PrivateArticleUploadCompleteAsync (long? articleId, long? fileId);

        /// <summary>
        /// Complete Upload
        /// </summary>
        /// <remarks>
        /// Complete file upload
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns>Task of ApiResponse</returns>
        System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleUploadCompleteAsyncWithHttpInfo (long? articleId, long? fileId);
        /// <summary>
        /// Initiate Upload
        /// </summary>
        /// <remarks>
        /// Initiate a new file upload within the article. Either use the link property to point to an existing file that resides elsewhere and will not be uploaded to Figshare or use the other 3 parameters (md5, name, size).
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="_file"></param>
        /// <returns>Task of Location</returns>
        System.Threading.Tasks.Task<Location> PrivateArticleUploadInitiateAsync (long? articleId, FileCreator _file);

        /// <summary>
        /// Initiate Upload
        /// </summary>
        /// <remarks>
        /// Initiate a new file upload within the article. Either use the link property to point to an existing file that resides elsewhere and will not be uploaded to Figshare or use the other 3 parameters (md5, name, size).
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="_file"></param>
        /// <returns>Task of ApiResponse (Location)</returns>
        System.Threading.Tasks.Task<ApiResponse<Location>> PrivateArticleUploadInitiateAsyncWithHttpInfo (long? articleId, FileCreator _file);
        /// <summary>
        /// Private Articles
        /// </summary>
        /// <remarks>
        /// Get Own Articles
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>Task of List&lt;Article&gt;</returns>
        System.Threading.Tasks.Task<List<Article>> PrivateArticlesListAsync (long? page = null, long? pageSize = null, long? limit = null, long? offset = null);

        /// <summary>
        /// Private Articles
        /// </summary>
        /// <remarks>
        /// Get Own Articles
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>Task of ApiResponse (List&lt;Article&gt;)</returns>
        System.Threading.Tasks.Task<ApiResponse<List<Article>>> PrivateArticlesListAsyncWithHttpInfo (long? page = null, long? pageSize = null, long? limit = null, long? offset = null);
        /// <summary>
        /// Private Articles search
        /// </summary>
        /// <remarks>
        /// Returns a list of private articles filtered by the search parameters
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="search">Search Parameters</param>
        /// <returns>Task of List&lt;ArticleWithProject&gt;</returns>
        System.Threading.Tasks.Task<List<ArticleWithProject>> PrivateArticlesSearchAsync (PrivateArticleSearch search);

        /// <summary>
        /// Private Articles search
        /// </summary>
        /// <remarks>
        /// Returns a list of private articles filtered by the search parameters
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="search">Search Parameters</param>
        /// <returns>Task of ApiResponse (List&lt;ArticleWithProject&gt;)</returns>
        System.Threading.Tasks.Task<ApiResponse<List<ArticleWithProject>>> PrivateArticlesSearchAsyncWithHttpInfo (PrivateArticleSearch search);
        #endregion Asynchronous Operations
    }

    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public partial class ArticlesApi : IArticlesApi
    {
        private IO.Swagger.Client.ExceptionFactory _exceptionFactory = (name, response) => null;

        /// <summary>
        /// Initializes a new instance of the <see cref="ArticlesApi"/> class.
        /// </summary>
        /// <returns></returns>
        public ArticlesApi(String basePath)
        {
            this.Configuration = new IO.Swagger.Client.Configuration { BasePath = basePath };

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="ArticlesApi"/> class
        /// using Configuration object
        /// </summary>
        /// <param name="configuration">An instance of Configuration</param>
        /// <returns></returns>
        public ArticlesApi(IO.Swagger.Client.Configuration configuration = null)
        {
            if (configuration == null) // use the default one in Configuration
                this.Configuration = IO.Swagger.Client.Configuration.Default;
            else
                this.Configuration = configuration;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;
        }

        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        public String GetBasePath()
        {
            return this.Configuration.ApiClient.RestClient.BaseUrl.ToString();
        }

        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        [Obsolete("SetBasePath is deprecated, please do 'Configuration.ApiClient = new ApiClient(\"http://new-path\")' instead.")]
        public void SetBasePath(String basePath)
        {
            // do nothing
        }

        /// <summary>
        /// Gets or sets the configuration object
        /// </summary>
        /// <value>An instance of the Configuration</value>
        public IO.Swagger.Client.Configuration Configuration {get; set;}

        /// <summary>
        /// Provides a factory method hook for the creation of exceptions.
        /// </summary>
        public IO.Swagger.Client.ExceptionFactory ExceptionFactory
        {
            get
            {
                if (_exceptionFactory != null && _exceptionFactory.GetInvocationList().Length > 1)
                {
                    throw new InvalidOperationException("Multicast delegate for ExceptionFactory is unsupported.");
                }
                return _exceptionFactory;
            }
            set { _exceptionFactory = value; }
        }

        /// <summary>
        /// Gets the default header.
        /// </summary>
        /// <returns>Dictionary of HTTP header</returns>
        [Obsolete("DefaultHeader is deprecated, please use Configuration.DefaultHeader instead.")]
        public IDictionary<String, String> DefaultHeader()
        {
            return new ReadOnlyDictionary<string, string>(this.Configuration.DefaultHeader);
        }

        /// <summary>
        /// Add default header.
        /// </summary>
        /// <param name="key">Header field name.</param>
        /// <param name="value">Header field value.</param>
        /// <returns></returns>
        [Obsolete("AddDefaultHeader is deprecated, please use Configuration.AddDefaultHeader instead.")]
        public void AddDefaultHeader(string key, string value)
        {
            this.Configuration.AddDefaultHeader(key, value);
        }

        /// <summary>
        /// Account Article Report Return status on all reports generated for the account from the oauth credentials
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="groupId">A group ID to filter by (optional)</param>
        /// <returns>List&lt;AccountReport&gt;</returns>
        public List<AccountReport> AccountArticleReport (long? groupId = null)
        {
             ApiResponse<List<AccountReport>> localVarResponse = AccountArticleReportWithHttpInfo(groupId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Account Article Report Return status on all reports generated for the account from the oauth credentials
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="groupId">A group ID to filter by (optional)</param>
        /// <returns>ApiResponse of List&lt;AccountReport&gt;</returns>
        public ApiResponse< List<AccountReport> > AccountArticleReportWithHttpInfo (long? groupId = null)
        {

            var localVarPath = "/account/articles/export";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (groupId != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "group_id", groupId)); // query parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("AccountArticleReport", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<AccountReport>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<AccountReport>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<AccountReport>)));
        }

        /// <summary>
        /// Account Article Report Return status on all reports generated for the account from the oauth credentials
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="groupId">A group ID to filter by (optional)</param>
        /// <returns>Task of List&lt;AccountReport&gt;</returns>
        public async System.Threading.Tasks.Task<List<AccountReport>> AccountArticleReportAsync (long? groupId = null)
        {
             ApiResponse<List<AccountReport>> localVarResponse = await AccountArticleReportAsyncWithHttpInfo(groupId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Account Article Report Return status on all reports generated for the account from the oauth credentials
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="groupId">A group ID to filter by (optional)</param>
        /// <returns>Task of ApiResponse (List&lt;AccountReport&gt;)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<List<AccountReport>>> AccountArticleReportAsyncWithHttpInfo (long? groupId = null)
        {

            var localVarPath = "/account/articles/export";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (groupId != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "group_id", groupId)); // query parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("AccountArticleReport", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<AccountReport>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<AccountReport>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<AccountReport>)));
        }

        /// <summary>
        /// Initiate a new Report Initiate a new Article Report for this Account. There is a limit of 1 report per day.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>AccountReport</returns>
        public AccountReport AccountArticleReportGenerate ()
        {
             ApiResponse<AccountReport> localVarResponse = AccountArticleReportGenerateWithHttpInfo();
             return localVarResponse.Data;
        }

        /// <summary>
        /// Initiate a new Report Initiate a new Article Report for this Account. There is a limit of 1 report per day.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>ApiResponse of AccountReport</returns>
        public ApiResponse< AccountReport > AccountArticleReportGenerateWithHttpInfo ()
        {

            var localVarPath = "/account/articles/export";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);


            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("AccountArticleReportGenerate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<AccountReport>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (AccountReport) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(AccountReport)));
        }

        /// <summary>
        /// Initiate a new Report Initiate a new Article Report for this Account. There is a limit of 1 report per day.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>Task of AccountReport</returns>
        public async System.Threading.Tasks.Task<AccountReport> AccountArticleReportGenerateAsync ()
        {
             ApiResponse<AccountReport> localVarResponse = await AccountArticleReportGenerateAsyncWithHttpInfo();
             return localVarResponse.Data;

        }

        /// <summary>
        /// Initiate a new Report Initiate a new Article Report for this Account. There is a limit of 1 report per day.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>Task of ApiResponse (AccountReport)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<AccountReport>> AccountArticleReportGenerateAsyncWithHttpInfo ()
        {

            var localVarPath = "/account/articles/export";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);


            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("AccountArticleReportGenerate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<AccountReport>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (AccountReport) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(AccountReport)));
        }

        /// <summary>
        /// View article details View an article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>ArticleComplete</returns>
        public ArticleComplete ArticleDetails (long? articleId)
        {
             ApiResponse<ArticleComplete> localVarResponse = ArticleDetailsWithHttpInfo(articleId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// View article details View an article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>ApiResponse of ArticleComplete</returns>
        public ApiResponse< ArticleComplete > ArticleDetailsWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->ArticleDetails");

            var localVarPath = "/articles/{article_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ArticleDetails", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<ArticleComplete>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (ArticleComplete) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(ArticleComplete)));
        }

        /// <summary>
        /// View article details View an article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>Task of ArticleComplete</returns>
        public async System.Threading.Tasks.Task<ArticleComplete> ArticleDetailsAsync (long? articleId)
        {
             ApiResponse<ArticleComplete> localVarResponse = await ArticleDetailsAsyncWithHttpInfo(articleId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// View article details View an article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>Task of ApiResponse (ArticleComplete)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<ArticleComplete>> ArticleDetailsAsyncWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->ArticleDetails");

            var localVarPath = "/articles/{article_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ArticleDetails", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<ArticleComplete>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (ArticleComplete) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(ArticleComplete)));
        }

        /// <summary>
        /// Article file details File by id
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="fileId">File Unique identifier</param>
        /// <returns>PublicFile</returns>
        public PublicFile ArticleFileDetails (long? articleId, long? fileId)
        {
             ApiResponse<PublicFile> localVarResponse = ArticleFileDetailsWithHttpInfo(articleId, fileId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Article file details File by id
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="fileId">File Unique identifier</param>
        /// <returns>ApiResponse of PublicFile</returns>
        public ApiResponse< PublicFile > ArticleFileDetailsWithHttpInfo (long? articleId, long? fileId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->ArticleFileDetails");
            // verify the required parameter 'fileId' is set
            if (fileId == null)
                throw new ApiException(400, "Missing required parameter 'fileId' when calling ArticlesApi->ArticleFileDetails");

            var localVarPath = "/articles/{article_id}/files/{file_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (fileId != null) localVarPathParams.Add("file_id", this.Configuration.ApiClient.ParameterToString(fileId)); // path parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ArticleFileDetails", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PublicFile>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PublicFile) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(PublicFile)));
        }

        /// <summary>
        /// Article file details File by id
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="fileId">File Unique identifier</param>
        /// <returns>Task of PublicFile</returns>
        public async System.Threading.Tasks.Task<PublicFile> ArticleFileDetailsAsync (long? articleId, long? fileId)
        {
             ApiResponse<PublicFile> localVarResponse = await ArticleFileDetailsAsyncWithHttpInfo(articleId, fileId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Article file details File by id
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="fileId">File Unique identifier</param>
        /// <returns>Task of ApiResponse (PublicFile)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PublicFile>> ArticleFileDetailsAsyncWithHttpInfo (long? articleId, long? fileId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->ArticleFileDetails");
            // verify the required parameter 'fileId' is set
            if (fileId == null)
                throw new ApiException(400, "Missing required parameter 'fileId' when calling ArticlesApi->ArticleFileDetails");

            var localVarPath = "/articles/{article_id}/files/{file_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (fileId != null) localVarPathParams.Add("file_id", this.Configuration.ApiClient.ParameterToString(fileId)); // path parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ArticleFileDetails", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PublicFile>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PublicFile) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(PublicFile)));
        }

        /// <summary>
        /// List article files Files list for article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>List&lt;PublicFile&gt;</returns>
        public List<PublicFile> ArticleFiles (long? articleId)
        {
             ApiResponse<List<PublicFile>> localVarResponse = ArticleFilesWithHttpInfo(articleId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// List article files Files list for article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>ApiResponse of List&lt;PublicFile&gt;</returns>
        public ApiResponse< List<PublicFile> > ArticleFilesWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->ArticleFiles");

            var localVarPath = "/articles/{article_id}/files";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ArticleFiles", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<PublicFile>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<PublicFile>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<PublicFile>)));
        }

        /// <summary>
        /// List article files Files list for article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>Task of List&lt;PublicFile&gt;</returns>
        public async System.Threading.Tasks.Task<List<PublicFile>> ArticleFilesAsync (long? articleId)
        {
             ApiResponse<List<PublicFile>> localVarResponse = await ArticleFilesAsyncWithHttpInfo(articleId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// List article files Files list for article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>Task of ApiResponse (List&lt;PublicFile&gt;)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<List<PublicFile>>> ArticleFilesAsyncWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->ArticleFiles");

            var localVarPath = "/articles/{article_id}/files";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ArticleFiles", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<PublicFile>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<PublicFile>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<PublicFile>)));
        }

        /// <summary>
        /// Public Article Confidentiality for article version Confidentiality for article version. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Version Number</param>
        /// <returns>ArticleConfidentiality</returns>
        public ArticleConfidentiality ArticleVersionConfidentiality (long? articleId, long? vNumber)
        {
             ApiResponse<ArticleConfidentiality> localVarResponse = ArticleVersionConfidentialityWithHttpInfo(articleId, vNumber);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Public Article Confidentiality for article version Confidentiality for article version. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Version Number</param>
        /// <returns>ApiResponse of ArticleConfidentiality</returns>
        public ApiResponse< ArticleConfidentiality > ArticleVersionConfidentialityWithHttpInfo (long? articleId, long? vNumber)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->ArticleVersionConfidentiality");
            // verify the required parameter 'vNumber' is set
            if (vNumber == null)
                throw new ApiException(400, "Missing required parameter 'vNumber' when calling ArticlesApi->ArticleVersionConfidentiality");

            var localVarPath = "/articles/{article_id}/versions/{v_number}/confidentiality";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (vNumber != null) localVarPathParams.Add("v_number", this.Configuration.ApiClient.ParameterToString(vNumber)); // path parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ArticleVersionConfidentiality", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<ArticleConfidentiality>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (ArticleConfidentiality) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(ArticleConfidentiality)));
        }

        /// <summary>
        /// Public Article Confidentiality for article version Confidentiality for article version. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Version Number</param>
        /// <returns>Task of ArticleConfidentiality</returns>
        public async System.Threading.Tasks.Task<ArticleConfidentiality> ArticleVersionConfidentialityAsync (long? articleId, long? vNumber)
        {
             ApiResponse<ArticleConfidentiality> localVarResponse = await ArticleVersionConfidentialityAsyncWithHttpInfo(articleId, vNumber);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Public Article Confidentiality for article version Confidentiality for article version. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Version Number</param>
        /// <returns>Task of ApiResponse (ArticleConfidentiality)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<ArticleConfidentiality>> ArticleVersionConfidentialityAsyncWithHttpInfo (long? articleId, long? vNumber)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->ArticleVersionConfidentiality");
            // verify the required parameter 'vNumber' is set
            if (vNumber == null)
                throw new ApiException(400, "Missing required parameter 'vNumber' when calling ArticlesApi->ArticleVersionConfidentiality");

            var localVarPath = "/articles/{article_id}/versions/{v_number}/confidentiality";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (vNumber != null) localVarPathParams.Add("v_number", this.Configuration.ApiClient.ParameterToString(vNumber)); // path parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ArticleVersionConfidentiality", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<ArticleConfidentiality>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (ArticleConfidentiality) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(ArticleConfidentiality)));
        }

        /// <summary>
        /// Article details for version Article with specified version
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Article Version Number</param>
        /// <returns>ArticleComplete</returns>
        public ArticleComplete ArticleVersionDetails (long? articleId, long? vNumber)
        {
             ApiResponse<ArticleComplete> localVarResponse = ArticleVersionDetailsWithHttpInfo(articleId, vNumber);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Article details for version Article with specified version
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Article Version Number</param>
        /// <returns>ApiResponse of ArticleComplete</returns>
        public ApiResponse< ArticleComplete > ArticleVersionDetailsWithHttpInfo (long? articleId, long? vNumber)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->ArticleVersionDetails");
            // verify the required parameter 'vNumber' is set
            if (vNumber == null)
                throw new ApiException(400, "Missing required parameter 'vNumber' when calling ArticlesApi->ArticleVersionDetails");

            var localVarPath = "/articles/{article_id}/versions/{v_number}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (vNumber != null) localVarPathParams.Add("v_number", this.Configuration.ApiClient.ParameterToString(vNumber)); // path parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ArticleVersionDetails", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<ArticleComplete>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (ArticleComplete) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(ArticleComplete)));
        }

        /// <summary>
        /// Article details for version Article with specified version
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Article Version Number</param>
        /// <returns>Task of ArticleComplete</returns>
        public async System.Threading.Tasks.Task<ArticleComplete> ArticleVersionDetailsAsync (long? articleId, long? vNumber)
        {
             ApiResponse<ArticleComplete> localVarResponse = await ArticleVersionDetailsAsyncWithHttpInfo(articleId, vNumber);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Article details for version Article with specified version
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Article Version Number</param>
        /// <returns>Task of ApiResponse (ArticleComplete)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<ArticleComplete>> ArticleVersionDetailsAsyncWithHttpInfo (long? articleId, long? vNumber)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->ArticleVersionDetails");
            // verify the required parameter 'vNumber' is set
            if (vNumber == null)
                throw new ApiException(400, "Missing required parameter 'vNumber' when calling ArticlesApi->ArticleVersionDetails");

            var localVarPath = "/articles/{article_id}/versions/{v_number}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (vNumber != null) localVarPathParams.Add("v_number", this.Configuration.ApiClient.ParameterToString(vNumber)); // path parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ArticleVersionDetails", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<ArticleComplete>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (ArticleComplete) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(ArticleComplete)));
        }

        /// <summary>
        /// Public Article Embargo for article version Embargo for article version
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Version Number</param>
        /// <returns>ArticleEmbargo</returns>
        public ArticleEmbargo ArticleVersionEmbargo (long? articleId, long? vNumber)
        {
             ApiResponse<ArticleEmbargo> localVarResponse = ArticleVersionEmbargoWithHttpInfo(articleId, vNumber);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Public Article Embargo for article version Embargo for article version
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Version Number</param>
        /// <returns>ApiResponse of ArticleEmbargo</returns>
        public ApiResponse< ArticleEmbargo > ArticleVersionEmbargoWithHttpInfo (long? articleId, long? vNumber)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->ArticleVersionEmbargo");
            // verify the required parameter 'vNumber' is set
            if (vNumber == null)
                throw new ApiException(400, "Missing required parameter 'vNumber' when calling ArticlesApi->ArticleVersionEmbargo");

            var localVarPath = "/articles/{article_id}/versions/{v_number}/embargo";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (vNumber != null) localVarPathParams.Add("v_number", this.Configuration.ApiClient.ParameterToString(vNumber)); // path parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ArticleVersionEmbargo", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<ArticleEmbargo>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (ArticleEmbargo) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(ArticleEmbargo)));
        }

        /// <summary>
        /// Public Article Embargo for article version Embargo for article version
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Version Number</param>
        /// <returns>Task of ArticleEmbargo</returns>
        public async System.Threading.Tasks.Task<ArticleEmbargo> ArticleVersionEmbargoAsync (long? articleId, long? vNumber)
        {
             ApiResponse<ArticleEmbargo> localVarResponse = await ArticleVersionEmbargoAsyncWithHttpInfo(articleId, vNumber);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Public Article Embargo for article version Embargo for article version
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <param name="vNumber">Version Number</param>
        /// <returns>Task of ApiResponse (ArticleEmbargo)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<ArticleEmbargo>> ArticleVersionEmbargoAsyncWithHttpInfo (long? articleId, long? vNumber)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->ArticleVersionEmbargo");
            // verify the required parameter 'vNumber' is set
            if (vNumber == null)
                throw new ApiException(400, "Missing required parameter 'vNumber' when calling ArticlesApi->ArticleVersionEmbargo");

            var localVarPath = "/articles/{article_id}/versions/{v_number}/embargo";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (vNumber != null) localVarPathParams.Add("v_number", this.Configuration.ApiClient.ParameterToString(vNumber)); // path parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ArticleVersionEmbargo", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<ArticleEmbargo>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (ArticleEmbargo) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(ArticleEmbargo)));
        }

        /// <summary>
        /// Update article version Updating an article version by passing body parameters; request can also be made with the PATCH method.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="versionId">Article version identifier</param>
        /// <param name="article">Article description</param>
        /// <returns>LocationWarningsUpdate</returns>
        public LocationWarningsUpdate ArticleVersionUpdate (long? articleId, long? versionId, ArticleUpdate article)
        {
             ApiResponse<LocationWarningsUpdate> localVarResponse = ArticleVersionUpdateWithHttpInfo(articleId, versionId, article);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Update article version Updating an article version by passing body parameters; request can also be made with the PATCH method.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="versionId">Article version identifier</param>
        /// <param name="article">Article description</param>
        /// <returns>ApiResponse of LocationWarningsUpdate</returns>
        public ApiResponse< LocationWarningsUpdate > ArticleVersionUpdateWithHttpInfo (long? articleId, long? versionId, ArticleUpdate article)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->ArticleVersionUpdate");
            // verify the required parameter 'versionId' is set
            if (versionId == null)
                throw new ApiException(400, "Missing required parameter 'versionId' when calling ArticlesApi->ArticleVersionUpdate");
            // verify the required parameter 'article' is set
            if (article == null)
                throw new ApiException(400, "Missing required parameter 'article' when calling ArticlesApi->ArticleVersionUpdate");

            var localVarPath = "/account/articles/{article_id}/versions/{version_id}/";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (versionId != null) localVarPathParams.Add("version_id", this.Configuration.ApiClient.ParameterToString(versionId)); // path parameter
            if (article != null && article.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(article); // http body (model) parameter
            }
            else
            {
                localVarPostBody = article; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ArticleVersionUpdate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<LocationWarningsUpdate>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (LocationWarningsUpdate) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(LocationWarningsUpdate)));
        }

        /// <summary>
        /// Update article version Updating an article version by passing body parameters; request can also be made with the PATCH method.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="versionId">Article version identifier</param>
        /// <param name="article">Article description</param>
        /// <returns>Task of LocationWarningsUpdate</returns>
        public async System.Threading.Tasks.Task<LocationWarningsUpdate> ArticleVersionUpdateAsync (long? articleId, long? versionId, ArticleUpdate article)
        {
             ApiResponse<LocationWarningsUpdate> localVarResponse = await ArticleVersionUpdateAsyncWithHttpInfo(articleId, versionId, article);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Update article version Updating an article version by passing body parameters; request can also be made with the PATCH method.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="versionId">Article version identifier</param>
        /// <param name="article">Article description</param>
        /// <returns>Task of ApiResponse (LocationWarningsUpdate)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<LocationWarningsUpdate>> ArticleVersionUpdateAsyncWithHttpInfo (long? articleId, long? versionId, ArticleUpdate article)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->ArticleVersionUpdate");
            // verify the required parameter 'versionId' is set
            if (versionId == null)
                throw new ApiException(400, "Missing required parameter 'versionId' when calling ArticlesApi->ArticleVersionUpdate");
            // verify the required parameter 'article' is set
            if (article == null)
                throw new ApiException(400, "Missing required parameter 'article' when calling ArticlesApi->ArticleVersionUpdate");

            var localVarPath = "/account/articles/{article_id}/versions/{version_id}/";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (versionId != null) localVarPathParams.Add("version_id", this.Configuration.ApiClient.ParameterToString(versionId)); // path parameter
            if (article != null && article.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(article); // http body (model) parameter
            }
            else
            {
                localVarPostBody = article; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ArticleVersionUpdate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<LocationWarningsUpdate>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (LocationWarningsUpdate) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(LocationWarningsUpdate)));
        }

        /// <summary>
        /// Update article version thumbnail For a given public article version update the article thumbnail by choosing one of the associated files
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="versionId">Article version identifier</param>
        /// <param name="fileId">File ID</param>
        /// <returns></returns>
        public void ArticleVersionUpdateThumb (long? articleId, long? versionId, FileId fileId)
        {
             ArticleVersionUpdateThumbWithHttpInfo(articleId, versionId, fileId);
        }

        /// <summary>
        /// Update article version thumbnail For a given public article version update the article thumbnail by choosing one of the associated files
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="versionId">Article version identifier</param>
        /// <param name="fileId">File ID</param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> ArticleVersionUpdateThumbWithHttpInfo (long? articleId, long? versionId, FileId fileId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->ArticleVersionUpdateThumb");
            // verify the required parameter 'versionId' is set
            if (versionId == null)
                throw new ApiException(400, "Missing required parameter 'versionId' when calling ArticlesApi->ArticleVersionUpdateThumb");
            // verify the required parameter 'fileId' is set
            if (fileId == null)
                throw new ApiException(400, "Missing required parameter 'fileId' when calling ArticlesApi->ArticleVersionUpdateThumb");

            var localVarPath = "/account/articles/{article_id}/versions/{version_id}/update_thumb";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (versionId != null) localVarPathParams.Add("version_id", this.Configuration.ApiClient.ParameterToString(versionId)); // path parameter
            if (fileId != null && fileId.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(fileId); // http body (model) parameter
            }
            else
            {
                localVarPostBody = fileId; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ArticleVersionUpdateThumb", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Update article version thumbnail For a given public article version update the article thumbnail by choosing one of the associated files
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="versionId">Article version identifier</param>
        /// <param name="fileId">File ID</param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task ArticleVersionUpdateThumbAsync (long? articleId, long? versionId, FileId fileId)
        {
             await ArticleVersionUpdateThumbAsyncWithHttpInfo(articleId, versionId, fileId);

        }

        /// <summary>
        /// Update article version thumbnail For a given public article version update the article thumbnail by choosing one of the associated files
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="versionId">Article version identifier</param>
        /// <param name="fileId">File ID</param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> ArticleVersionUpdateThumbAsyncWithHttpInfo (long? articleId, long? versionId, FileId fileId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->ArticleVersionUpdateThumb");
            // verify the required parameter 'versionId' is set
            if (versionId == null)
                throw new ApiException(400, "Missing required parameter 'versionId' when calling ArticlesApi->ArticleVersionUpdateThumb");
            // verify the required parameter 'fileId' is set
            if (fileId == null)
                throw new ApiException(400, "Missing required parameter 'fileId' when calling ArticlesApi->ArticleVersionUpdateThumb");

            var localVarPath = "/account/articles/{article_id}/versions/{version_id}/update_thumb";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (versionId != null) localVarPathParams.Add("version_id", this.Configuration.ApiClient.ParameterToString(versionId)); // path parameter
            if (fileId != null && fileId.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(fileId); // http body (model) parameter
            }
            else
            {
                localVarPostBody = fileId; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ArticleVersionUpdateThumb", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// List article versions List public article versions
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>List&lt;ArticleVersions&gt;</returns>
        public List<ArticleVersions> ArticleVersions (long? articleId)
        {
             ApiResponse<List<ArticleVersions>> localVarResponse = ArticleVersionsWithHttpInfo(articleId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// List article versions List public article versions
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>ApiResponse of List&lt;ArticleVersions&gt;</returns>
        public ApiResponse< List<ArticleVersions> > ArticleVersionsWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->ArticleVersions");

            var localVarPath = "/articles/{article_id}/versions";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ArticleVersions", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<ArticleVersions>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<ArticleVersions>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<ArticleVersions>)));
        }

        /// <summary>
        /// List article versions List public article versions
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>Task of List&lt;ArticleVersions&gt;</returns>
        public async System.Threading.Tasks.Task<List<ArticleVersions>> ArticleVersionsAsync (long? articleId)
        {
             ApiResponse<List<ArticleVersions>> localVarResponse = await ArticleVersionsAsyncWithHttpInfo(articleId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// List article versions List public article versions
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article Unique identifier</param>
        /// <returns>Task of ApiResponse (List&lt;ArticleVersions&gt;)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<List<ArticleVersions>>> ArticleVersionsAsyncWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->ArticleVersions");

            var localVarPath = "/articles/{article_id}/versions";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ArticleVersions", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<ArticleVersions>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<ArticleVersions>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<ArticleVersions>)));
        }

        /// <summary>
        /// Public Articles Returns a list of public articles
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <param name="institution">only return articles from this institution (optional)</param>
        /// <param name="publishedSince">Filter by article publishing date. Will only return articles published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="modifiedSince">Filter by article modified date. Will only return articles published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="group">only return articles from this group (optional)</param>
        /// <param name="resourceDoi">only return articles with this resource_doi (optional)</param>
        /// <param name="itemType">Only return articles with the respective type. Mapping for item_type is: 1 - Figure, 2 - Media, 3 - Dataset, 5 - Poster, 6 - Journal contribution, 7 - Presentation, 8 - Thesis, 9 - Software, 11 - Online resource, 12 - Preprint, 13 - Book, 14 - Conference contribution, 15 - Chapter, 16 - Peer review, 17 - Educational resource, 18 - Report, 19 - Standard, 20 - Composition, 21 - Funding, 22 - Physical object, 23 - Data management plan, 24 - Workflow, 25 - Monograph, 26 - Performance, 27 - Event, 28 - Service, 29 - Model (optional)</param>
        /// <param name="doi">only return articles with this doi (optional)</param>
        /// <param name="handle">only return articles with this handle (optional)</param>
        /// <returns>List&lt;Article&gt;</returns>
        public List<Article> ArticlesList (Guid? xCursor = null, long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null, long? institution = null, string publishedSince = null, string modifiedSince = null, long? group = null, string resourceDoi = null, long? itemType = null, string doi = null, string handle = null)
        {
             ApiResponse<List<Article>> localVarResponse = ArticlesListWithHttpInfo(xCursor, page, pageSize, limit, offset, order, orderDirection, institution, publishedSince, modifiedSince, group, resourceDoi, itemType, doi, handle);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Public Articles Returns a list of public articles
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <param name="institution">only return articles from this institution (optional)</param>
        /// <param name="publishedSince">Filter by article publishing date. Will only return articles published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="modifiedSince">Filter by article modified date. Will only return articles published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="group">only return articles from this group (optional)</param>
        /// <param name="resourceDoi">only return articles with this resource_doi (optional)</param>
        /// <param name="itemType">Only return articles with the respective type. Mapping for item_type is: 1 - Figure, 2 - Media, 3 - Dataset, 5 - Poster, 6 - Journal contribution, 7 - Presentation, 8 - Thesis, 9 - Software, 11 - Online resource, 12 - Preprint, 13 - Book, 14 - Conference contribution, 15 - Chapter, 16 - Peer review, 17 - Educational resource, 18 - Report, 19 - Standard, 20 - Composition, 21 - Funding, 22 - Physical object, 23 - Data management plan, 24 - Workflow, 25 - Monograph, 26 - Performance, 27 - Event, 28 - Service, 29 - Model (optional)</param>
        /// <param name="doi">only return articles with this doi (optional)</param>
        /// <param name="handle">only return articles with this handle (optional)</param>
        /// <returns>ApiResponse of List&lt;Article&gt;</returns>
        public ApiResponse< List<Article> > ArticlesListWithHttpInfo (Guid? xCursor = null, long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null, long? institution = null, string publishedSince = null, string modifiedSince = null, long? group = null, string resourceDoi = null, long? itemType = null, string doi = null, string handle = null)
        {

            var localVarPath = "/articles";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (page != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page", page)); // query parameter
            if (pageSize != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page_size", pageSize)); // query parameter
            if (limit != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "limit", limit)); // query parameter
            if (offset != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "offset", offset)); // query parameter
            if (order != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "order", order)); // query parameter
            if (orderDirection != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "order_direction", orderDirection)); // query parameter
            if (institution != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "institution", institution)); // query parameter
            if (publishedSince != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "published_since", publishedSince)); // query parameter
            if (modifiedSince != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "modified_since", modifiedSince)); // query parameter
            if (group != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "group", group)); // query parameter
            if (resourceDoi != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "resource_doi", resourceDoi)); // query parameter
            if (itemType != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "item_type", itemType)); // query parameter
            if (doi != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "doi", doi)); // query parameter
            if (handle != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "handle", handle)); // query parameter
            if (xCursor != null) localVarHeaderParams.Add("X-Cursor", this.Configuration.ApiClient.ParameterToString(xCursor)); // header parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ArticlesList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Article>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Article>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Article>)));
        }

        /// <summary>
        /// Public Articles Returns a list of public articles
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <param name="institution">only return articles from this institution (optional)</param>
        /// <param name="publishedSince">Filter by article publishing date. Will only return articles published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="modifiedSince">Filter by article modified date. Will only return articles published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="group">only return articles from this group (optional)</param>
        /// <param name="resourceDoi">only return articles with this resource_doi (optional)</param>
        /// <param name="itemType">Only return articles with the respective type. Mapping for item_type is: 1 - Figure, 2 - Media, 3 - Dataset, 5 - Poster, 6 - Journal contribution, 7 - Presentation, 8 - Thesis, 9 - Software, 11 - Online resource, 12 - Preprint, 13 - Book, 14 - Conference contribution, 15 - Chapter, 16 - Peer review, 17 - Educational resource, 18 - Report, 19 - Standard, 20 - Composition, 21 - Funding, 22 - Physical object, 23 - Data management plan, 24 - Workflow, 25 - Monograph, 26 - Performance, 27 - Event, 28 - Service, 29 - Model (optional)</param>
        /// <param name="doi">only return articles with this doi (optional)</param>
        /// <param name="handle">only return articles with this handle (optional)</param>
        /// <returns>Task of List&lt;Article&gt;</returns>
        public async System.Threading.Tasks.Task<List<Article>> ArticlesListAsync (Guid? xCursor = null, long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null, long? institution = null, string publishedSince = null, string modifiedSince = null, long? group = null, string resourceDoi = null, long? itemType = null, string doi = null, string handle = null)
        {
             ApiResponse<List<Article>> localVarResponse = await ArticlesListAsyncWithHttpInfo(xCursor, page, pageSize, limit, offset, order, orderDirection, institution, publishedSince, modifiedSince, group, resourceDoi, itemType, doi, handle);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Public Articles Returns a list of public articles
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <param name="order">The field by which to order. Default varies by endpoint/resource. (optional, default to published_date)</param>
        /// <param name="orderDirection"> (optional, default to desc)</param>
        /// <param name="institution">only return articles from this institution (optional)</param>
        /// <param name="publishedSince">Filter by article publishing date. Will only return articles published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="modifiedSince">Filter by article modified date. Will only return articles published after the date. date(ISO 8601) YYYY-MM-DD (optional)</param>
        /// <param name="group">only return articles from this group (optional)</param>
        /// <param name="resourceDoi">only return articles with this resource_doi (optional)</param>
        /// <param name="itemType">Only return articles with the respective type. Mapping for item_type is: 1 - Figure, 2 - Media, 3 - Dataset, 5 - Poster, 6 - Journal contribution, 7 - Presentation, 8 - Thesis, 9 - Software, 11 - Online resource, 12 - Preprint, 13 - Book, 14 - Conference contribution, 15 - Chapter, 16 - Peer review, 17 - Educational resource, 18 - Report, 19 - Standard, 20 - Composition, 21 - Funding, 22 - Physical object, 23 - Data management plan, 24 - Workflow, 25 - Monograph, 26 - Performance, 27 - Event, 28 - Service, 29 - Model (optional)</param>
        /// <param name="doi">only return articles with this doi (optional)</param>
        /// <param name="handle">only return articles with this handle (optional)</param>
        /// <returns>Task of ApiResponse (List&lt;Article&gt;)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<List<Article>>> ArticlesListAsyncWithHttpInfo (Guid? xCursor = null, long? page = null, long? pageSize = null, long? limit = null, long? offset = null, string order = null, string orderDirection = null, long? institution = null, string publishedSince = null, string modifiedSince = null, long? group = null, string resourceDoi = null, long? itemType = null, string doi = null, string handle = null)
        {

            var localVarPath = "/articles";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (page != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page", page)); // query parameter
            if (pageSize != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page_size", pageSize)); // query parameter
            if (limit != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "limit", limit)); // query parameter
            if (offset != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "offset", offset)); // query parameter
            if (order != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "order", order)); // query parameter
            if (orderDirection != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "order_direction", orderDirection)); // query parameter
            if (institution != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "institution", institution)); // query parameter
            if (publishedSince != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "published_since", publishedSince)); // query parameter
            if (modifiedSince != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "modified_since", modifiedSince)); // query parameter
            if (group != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "group", group)); // query parameter
            if (resourceDoi != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "resource_doi", resourceDoi)); // query parameter
            if (itemType != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "item_type", itemType)); // query parameter
            if (doi != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "doi", doi)); // query parameter
            if (handle != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "handle", handle)); // query parameter
            if (xCursor != null) localVarHeaderParams.Add("X-Cursor", this.Configuration.ApiClient.ParameterToString(xCursor)); // header parameter


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ArticlesList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Article>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Article>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Article>)));
        }

        /// <summary>
        /// Public Articles Search Returns a list of public articles, filtered by the search parameters
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="search">Search Parameters (optional)</param>
        /// <returns>List&lt;ArticleWithProject&gt;</returns>
        public List<ArticleWithProject> ArticlesSearch (Guid? xCursor = null, ArticleSearch search = null)
        {
             ApiResponse<List<ArticleWithProject>> localVarResponse = ArticlesSearchWithHttpInfo(xCursor, search);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Public Articles Search Returns a list of public articles, filtered by the search parameters
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="search">Search Parameters (optional)</param>
        /// <returns>ApiResponse of List&lt;ArticleWithProject&gt;</returns>
        public ApiResponse< List<ArticleWithProject> > ArticlesSearchWithHttpInfo (Guid? xCursor = null, ArticleSearch search = null)
        {

            var localVarPath = "/articles/search";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (xCursor != null) localVarHeaderParams.Add("X-Cursor", this.Configuration.ApiClient.ParameterToString(xCursor)); // header parameter
            if (search != null && search.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(search); // http body (model) parameter
            }
            else
            {
                localVarPostBody = search; // byte array
            }


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ArticlesSearch", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<ArticleWithProject>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<ArticleWithProject>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<ArticleWithProject>)));
        }

        /// <summary>
        /// Public Articles Search Returns a list of public articles, filtered by the search parameters
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="search">Search Parameters (optional)</param>
        /// <returns>Task of List&lt;ArticleWithProject&gt;</returns>
        public async System.Threading.Tasks.Task<List<ArticleWithProject>> ArticlesSearchAsync (Guid? xCursor = null, ArticleSearch search = null)
        {
             ApiResponse<List<ArticleWithProject>> localVarResponse = await ArticlesSearchAsyncWithHttpInfo(xCursor, search);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Public Articles Search Returns a list of public articles, filtered by the search parameters
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="xCursor">Unique hash used for bypassing the item retrieval limit of 9,000 entities. When using this parameter, please note that the offset parameter will not be available, but the limit parameter will still work as expected. (optional)</param>
        /// <param name="search">Search Parameters (optional)</param>
        /// <returns>Task of ApiResponse (List&lt;ArticleWithProject&gt;)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<List<ArticleWithProject>>> ArticlesSearchAsyncWithHttpInfo (Guid? xCursor = null, ArticleSearch search = null)
        {

            var localVarPath = "/articles/search";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (xCursor != null) localVarHeaderParams.Add("X-Cursor", this.Configuration.ApiClient.ParameterToString(xCursor)); // header parameter
            if (search != null && search.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(search); // http body (model) parameter
            }
            else
            {
                localVarPostBody = search; // byte array
            }


            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ArticlesSearch", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<ArticleWithProject>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<ArticleWithProject>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<ArticleWithProject>)));
        }

        /// <summary>
        /// Delete article author De-associate author from article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authorId">Article Author unique identifier</param>
        /// <returns></returns>
        public void PrivateArticleAuthorDelete (long? articleId, long? authorId)
        {
             PrivateArticleAuthorDeleteWithHttpInfo(articleId, authorId);
        }

        /// <summary>
        /// Delete article author De-associate author from article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authorId">Article Author unique identifier</param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateArticleAuthorDeleteWithHttpInfo (long? articleId, long? authorId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleAuthorDelete");
            // verify the required parameter 'authorId' is set
            if (authorId == null)
                throw new ApiException(400, "Missing required parameter 'authorId' when calling ArticlesApi->PrivateArticleAuthorDelete");

            var localVarPath = "/account/articles/{article_id}/authors/{author_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (authorId != null) localVarPathParams.Add("author_id", this.Configuration.ApiClient.ParameterToString(authorId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleAuthorDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Delete article author De-associate author from article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authorId">Article Author unique identifier</param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateArticleAuthorDeleteAsync (long? articleId, long? authorId)
        {
             await PrivateArticleAuthorDeleteAsyncWithHttpInfo(articleId, authorId);

        }

        /// <summary>
        /// Delete article author De-associate author from article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authorId">Article Author unique identifier</param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleAuthorDeleteAsyncWithHttpInfo (long? articleId, long? authorId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleAuthorDelete");
            // verify the required parameter 'authorId' is set
            if (authorId == null)
                throw new ApiException(400, "Missing required parameter 'authorId' when calling ArticlesApi->PrivateArticleAuthorDelete");

            var localVarPath = "/account/articles/{article_id}/authors/{author_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (authorId != null) localVarPathParams.Add("author_id", this.Configuration.ApiClient.ParameterToString(authorId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleAuthorDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Add article authors Associate new authors with the article. This will add new authors to the list of already associated authors
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authors">Authors description</param>
        /// <returns></returns>
        public void PrivateArticleAuthorsAdd (long? articleId, AuthorsCreator authors)
        {
             PrivateArticleAuthorsAddWithHttpInfo(articleId, authors);
        }

        /// <summary>
        /// Add article authors Associate new authors with the article. This will add new authors to the list of already associated authors
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authors">Authors description</param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateArticleAuthorsAddWithHttpInfo (long? articleId, AuthorsCreator authors)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleAuthorsAdd");
            // verify the required parameter 'authors' is set
            if (authors == null)
                throw new ApiException(400, "Missing required parameter 'authors' when calling ArticlesApi->PrivateArticleAuthorsAdd");

            var localVarPath = "/account/articles/{article_id}/authors";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (authors != null && authors.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(authors); // http body (model) parameter
            }
            else
            {
                localVarPostBody = authors; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleAuthorsAdd", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Add article authors Associate new authors with the article. This will add new authors to the list of already associated authors
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authors">Authors description</param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateArticleAuthorsAddAsync (long? articleId, AuthorsCreator authors)
        {
             await PrivateArticleAuthorsAddAsyncWithHttpInfo(articleId, authors);

        }

        /// <summary>
        /// Add article authors Associate new authors with the article. This will add new authors to the list of already associated authors
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authors">Authors description</param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleAuthorsAddAsyncWithHttpInfo (long? articleId, AuthorsCreator authors)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleAuthorsAdd");
            // verify the required parameter 'authors' is set
            if (authors == null)
                throw new ApiException(400, "Missing required parameter 'authors' when calling ArticlesApi->PrivateArticleAuthorsAdd");

            var localVarPath = "/account/articles/{article_id}/authors";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (authors != null && authors.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(authors); // http body (model) parameter
            }
            else
            {
                localVarPostBody = authors; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleAuthorsAdd", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// List article authors List article authors
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>List&lt;Author&gt;</returns>
        public List<Author> PrivateArticleAuthorsList (long? articleId)
        {
             ApiResponse<List<Author>> localVarResponse = PrivateArticleAuthorsListWithHttpInfo(articleId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// List article authors List article authors
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of List&lt;Author&gt;</returns>
        public ApiResponse< List<Author> > PrivateArticleAuthorsListWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleAuthorsList");

            var localVarPath = "/account/articles/{article_id}/authors";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleAuthorsList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Author>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Author>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Author>)));
        }

        /// <summary>
        /// List article authors List article authors
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of List&lt;Author&gt;</returns>
        public async System.Threading.Tasks.Task<List<Author>> PrivateArticleAuthorsListAsync (long? articleId)
        {
             ApiResponse<List<Author>> localVarResponse = await PrivateArticleAuthorsListAsyncWithHttpInfo(articleId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// List article authors List article authors
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse (List&lt;Author&gt;)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<List<Author>>> PrivateArticleAuthorsListAsyncWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleAuthorsList");

            var localVarPath = "/account/articles/{article_id}/authors";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleAuthorsList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Author>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Author>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Author>)));
        }

        /// <summary>
        /// Replace article authors Associate new authors with the article. This will remove all already associated authors and add these new ones
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authors">Authors description</param>
        /// <returns></returns>
        public void PrivateArticleAuthorsReplace (long? articleId, AuthorsCreator authors)
        {
             PrivateArticleAuthorsReplaceWithHttpInfo(articleId, authors);
        }

        /// <summary>
        /// Replace article authors Associate new authors with the article. This will remove all already associated authors and add these new ones
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authors">Authors description</param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateArticleAuthorsReplaceWithHttpInfo (long? articleId, AuthorsCreator authors)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleAuthorsReplace");
            // verify the required parameter 'authors' is set
            if (authors == null)
                throw new ApiException(400, "Missing required parameter 'authors' when calling ArticlesApi->PrivateArticleAuthorsReplace");

            var localVarPath = "/account/articles/{article_id}/authors";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (authors != null && authors.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(authors); // http body (model) parameter
            }
            else
            {
                localVarPostBody = authors; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleAuthorsReplace", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Replace article authors Associate new authors with the article. This will remove all already associated authors and add these new ones
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authors">Authors description</param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateArticleAuthorsReplaceAsync (long? articleId, AuthorsCreator authors)
        {
             await PrivateArticleAuthorsReplaceAsyncWithHttpInfo(articleId, authors);

        }

        /// <summary>
        /// Replace article authors Associate new authors with the article. This will remove all already associated authors and add these new ones
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="authors">Authors description</param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleAuthorsReplaceAsyncWithHttpInfo (long? articleId, AuthorsCreator authors)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleAuthorsReplace");
            // verify the required parameter 'authors' is set
            if (authors == null)
                throw new ApiException(400, "Missing required parameter 'authors' when calling ArticlesApi->PrivateArticleAuthorsReplace");

            var localVarPath = "/account/articles/{article_id}/authors";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (authors != null && authors.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(authors); // http body (model) parameter
            }
            else
            {
                localVarPostBody = authors; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleAuthorsReplace", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Add article categories Associate new categories with the article. This will add new categories to the list of already associated categories
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categories"></param>
        /// <returns></returns>
        public void PrivateArticleCategoriesAdd (long? articleId, CategoriesCreator categories)
        {
             PrivateArticleCategoriesAddWithHttpInfo(articleId, categories);
        }

        /// <summary>
        /// Add article categories Associate new categories with the article. This will add new categories to the list of already associated categories
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categories"></param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateArticleCategoriesAddWithHttpInfo (long? articleId, CategoriesCreator categories)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleCategoriesAdd");
            // verify the required parameter 'categories' is set
            if (categories == null)
                throw new ApiException(400, "Missing required parameter 'categories' when calling ArticlesApi->PrivateArticleCategoriesAdd");

            var localVarPath = "/account/articles/{article_id}/categories";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (categories != null && categories.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(categories); // http body (model) parameter
            }
            else
            {
                localVarPostBody = categories; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleCategoriesAdd", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Add article categories Associate new categories with the article. This will add new categories to the list of already associated categories
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categories"></param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateArticleCategoriesAddAsync (long? articleId, CategoriesCreator categories)
        {
             await PrivateArticleCategoriesAddAsyncWithHttpInfo(articleId, categories);

        }

        /// <summary>
        /// Add article categories Associate new categories with the article. This will add new categories to the list of already associated categories
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categories"></param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleCategoriesAddAsyncWithHttpInfo (long? articleId, CategoriesCreator categories)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleCategoriesAdd");
            // verify the required parameter 'categories' is set
            if (categories == null)
                throw new ApiException(400, "Missing required parameter 'categories' when calling ArticlesApi->PrivateArticleCategoriesAdd");

            var localVarPath = "/account/articles/{article_id}/categories";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (categories != null && categories.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(categories); // http body (model) parameter
            }
            else
            {
                localVarPostBody = categories; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleCategoriesAdd", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// List article categories List article categories
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>List&lt;Category&gt;</returns>
        public List<Category> PrivateArticleCategoriesList (long? articleId)
        {
             ApiResponse<List<Category>> localVarResponse = PrivateArticleCategoriesListWithHttpInfo(articleId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// List article categories List article categories
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of List&lt;Category&gt;</returns>
        public ApiResponse< List<Category> > PrivateArticleCategoriesListWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleCategoriesList");

            var localVarPath = "/account/articles/{article_id}/categories";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleCategoriesList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Category>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Category>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Category>)));
        }

        /// <summary>
        /// List article categories List article categories
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of List&lt;Category&gt;</returns>
        public async System.Threading.Tasks.Task<List<Category>> PrivateArticleCategoriesListAsync (long? articleId)
        {
             ApiResponse<List<Category>> localVarResponse = await PrivateArticleCategoriesListAsyncWithHttpInfo(articleId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// List article categories List article categories
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse (List&lt;Category&gt;)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<List<Category>>> PrivateArticleCategoriesListAsyncWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleCategoriesList");

            var localVarPath = "/account/articles/{article_id}/categories";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleCategoriesList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Category>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Category>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Category>)));
        }

        /// <summary>
        /// Replace article categories Associate new categories with the article. This will remove all already associated categories and add these new ones
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categories"></param>
        /// <returns></returns>
        public void PrivateArticleCategoriesReplace (long? articleId, CategoriesCreator categories)
        {
             PrivateArticleCategoriesReplaceWithHttpInfo(articleId, categories);
        }

        /// <summary>
        /// Replace article categories Associate new categories with the article. This will remove all already associated categories and add these new ones
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categories"></param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateArticleCategoriesReplaceWithHttpInfo (long? articleId, CategoriesCreator categories)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleCategoriesReplace");
            // verify the required parameter 'categories' is set
            if (categories == null)
                throw new ApiException(400, "Missing required parameter 'categories' when calling ArticlesApi->PrivateArticleCategoriesReplace");

            var localVarPath = "/account/articles/{article_id}/categories";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (categories != null && categories.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(categories); // http body (model) parameter
            }
            else
            {
                localVarPostBody = categories; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleCategoriesReplace", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Replace article categories Associate new categories with the article. This will remove all already associated categories and add these new ones
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categories"></param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateArticleCategoriesReplaceAsync (long? articleId, CategoriesCreator categories)
        {
             await PrivateArticleCategoriesReplaceAsyncWithHttpInfo(articleId, categories);

        }

        /// <summary>
        /// Replace article categories Associate new categories with the article. This will remove all already associated categories and add these new ones
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categories"></param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleCategoriesReplaceAsyncWithHttpInfo (long? articleId, CategoriesCreator categories)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleCategoriesReplace");
            // verify the required parameter 'categories' is set
            if (categories == null)
                throw new ApiException(400, "Missing required parameter 'categories' when calling ArticlesApi->PrivateArticleCategoriesReplace");

            var localVarPath = "/account/articles/{article_id}/categories";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (categories != null && categories.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(categories); // http body (model) parameter
            }
            else
            {
                localVarPostBody = categories; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleCategoriesReplace", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Delete article category De-associate category from article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categoryId">Category unique identifier</param>
        /// <returns></returns>
        public void PrivateArticleCategoryDelete (long? articleId, long? categoryId)
        {
             PrivateArticleCategoryDeleteWithHttpInfo(articleId, categoryId);
        }

        /// <summary>
        /// Delete article category De-associate category from article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categoryId">Category unique identifier</param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateArticleCategoryDeleteWithHttpInfo (long? articleId, long? categoryId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleCategoryDelete");
            // verify the required parameter 'categoryId' is set
            if (categoryId == null)
                throw new ApiException(400, "Missing required parameter 'categoryId' when calling ArticlesApi->PrivateArticleCategoryDelete");

            var localVarPath = "/account/articles/{article_id}/categories/{category_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (categoryId != null) localVarPathParams.Add("category_id", this.Configuration.ApiClient.ParameterToString(categoryId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleCategoryDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Delete article category De-associate category from article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categoryId">Category unique identifier</param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateArticleCategoryDeleteAsync (long? articleId, long? categoryId)
        {
             await PrivateArticleCategoryDeleteAsyncWithHttpInfo(articleId, categoryId);

        }

        /// <summary>
        /// Delete article category De-associate category from article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="categoryId">Category unique identifier</param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleCategoryDeleteAsyncWithHttpInfo (long? articleId, long? categoryId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleCategoryDelete");
            // verify the required parameter 'categoryId' is set
            if (categoryId == null)
                throw new ApiException(400, "Missing required parameter 'categoryId' when calling ArticlesApi->PrivateArticleCategoryDelete");

            var localVarPath = "/account/articles/{article_id}/categories/{category_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (categoryId != null) localVarPathParams.Add("category_id", this.Configuration.ApiClient.ParameterToString(categoryId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleCategoryDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Delete article confidentiality Delete confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns></returns>
        public void PrivateArticleConfidentialityDelete (long? articleId)
        {
             PrivateArticleConfidentialityDeleteWithHttpInfo(articleId);
        }

        /// <summary>
        /// Delete article confidentiality Delete confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateArticleConfidentialityDeleteWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleConfidentialityDelete");

            var localVarPath = "/account/articles/{article_id}/confidentiality";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleConfidentialityDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Delete article confidentiality Delete confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateArticleConfidentialityDeleteAsync (long? articleId)
        {
             await PrivateArticleConfidentialityDeleteAsyncWithHttpInfo(articleId);

        }

        /// <summary>
        /// Delete article confidentiality Delete confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleConfidentialityDeleteAsyncWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleConfidentialityDelete");

            var localVarPath = "/account/articles/{article_id}/confidentiality";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleConfidentialityDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Article confidentiality details View confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ArticleConfidentiality</returns>
        public ArticleConfidentiality PrivateArticleConfidentialityDetails (long? articleId)
        {
             ApiResponse<ArticleConfidentiality> localVarResponse = PrivateArticleConfidentialityDetailsWithHttpInfo(articleId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Article confidentiality details View confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of ArticleConfidentiality</returns>
        public ApiResponse< ArticleConfidentiality > PrivateArticleConfidentialityDetailsWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleConfidentialityDetails");

            var localVarPath = "/account/articles/{article_id}/confidentiality";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleConfidentialityDetails", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<ArticleConfidentiality>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (ArticleConfidentiality) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(ArticleConfidentiality)));
        }

        /// <summary>
        /// Article confidentiality details View confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ArticleConfidentiality</returns>
        public async System.Threading.Tasks.Task<ArticleConfidentiality> PrivateArticleConfidentialityDetailsAsync (long? articleId)
        {
             ApiResponse<ArticleConfidentiality> localVarResponse = await PrivateArticleConfidentialityDetailsAsyncWithHttpInfo(articleId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Article confidentiality details View confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse (ArticleConfidentiality)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<ArticleConfidentiality>> PrivateArticleConfidentialityDetailsAsyncWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleConfidentialityDetails");

            var localVarPath = "/account/articles/{article_id}/confidentiality";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleConfidentialityDetails", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<ArticleConfidentiality>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (ArticleConfidentiality) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(ArticleConfidentiality)));
        }

        /// <summary>
        /// Update article confidentiality Update confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="reason"></param>
        /// <returns></returns>
        public void PrivateArticleConfidentialityUpdate (long? articleId, ConfidentialityCreator reason)
        {
             PrivateArticleConfidentialityUpdateWithHttpInfo(articleId, reason);
        }

        /// <summary>
        /// Update article confidentiality Update confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="reason"></param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateArticleConfidentialityUpdateWithHttpInfo (long? articleId, ConfidentialityCreator reason)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleConfidentialityUpdate");
            // verify the required parameter 'reason' is set
            if (reason == null)
                throw new ApiException(400, "Missing required parameter 'reason' when calling ArticlesApi->PrivateArticleConfidentialityUpdate");

            var localVarPath = "/account/articles/{article_id}/confidentiality";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (reason != null && reason.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(reason); // http body (model) parameter
            }
            else
            {
                localVarPostBody = reason; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleConfidentialityUpdate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Update article confidentiality Update confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="reason"></param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateArticleConfidentialityUpdateAsync (long? articleId, ConfidentialityCreator reason)
        {
             await PrivateArticleConfidentialityUpdateAsyncWithHttpInfo(articleId, reason);

        }

        /// <summary>
        /// Update article confidentiality Update confidentiality settings. The confidentiality feature is now deprecated. This has been replaced by the new extended embargo functionality and all items that used to be confidential have now been migrated to items with a permanent embargo on files. All API endpoints related to this functionality will remain for backwards compatibility, but will now be attached to the new extended embargo workflows.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="reason"></param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleConfidentialityUpdateAsyncWithHttpInfo (long? articleId, ConfidentialityCreator reason)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleConfidentialityUpdate");
            // verify the required parameter 'reason' is set
            if (reason == null)
                throw new ApiException(400, "Missing required parameter 'reason' when calling ArticlesApi->PrivateArticleConfidentialityUpdate");

            var localVarPath = "/account/articles/{article_id}/confidentiality";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (reason != null && reason.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(reason); // http body (model) parameter
            }
            else
            {
                localVarPostBody = reason; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleConfidentialityUpdate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Create new Article Create a new Article by sending article information
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="article">Article description</param>
        /// <returns>LocationWarnings</returns>
        public LocationWarnings PrivateArticleCreate (ArticleCreate article)
        {
             ApiResponse<LocationWarnings> localVarResponse = PrivateArticleCreateWithHttpInfo(article);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Create new Article Create a new Article by sending article information
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="article">Article description</param>
        /// <returns>ApiResponse of LocationWarnings</returns>
        public ApiResponse< LocationWarnings > PrivateArticleCreateWithHttpInfo (ArticleCreate article)
        {
            // verify the required parameter 'article' is set
            if (article == null)
                throw new ApiException(400, "Missing required parameter 'article' when calling ArticlesApi->PrivateArticleCreate");

            var localVarPath = "/account/articles";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (article != null && article.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(article); // http body (model) parameter
            }
            else
            {
                localVarPostBody = article; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleCreate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<LocationWarnings>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (LocationWarnings) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(LocationWarnings)));
        }

        /// <summary>
        /// Create new Article Create a new Article by sending article information
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="article">Article description</param>
        /// <returns>Task of LocationWarnings</returns>
        public async System.Threading.Tasks.Task<LocationWarnings> PrivateArticleCreateAsync (ArticleCreate article)
        {
             ApiResponse<LocationWarnings> localVarResponse = await PrivateArticleCreateAsyncWithHttpInfo(article);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Create new Article Create a new Article by sending article information
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="article">Article description</param>
        /// <returns>Task of ApiResponse (LocationWarnings)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<LocationWarnings>> PrivateArticleCreateAsyncWithHttpInfo (ArticleCreate article)
        {
            // verify the required parameter 'article' is set
            if (article == null)
                throw new ApiException(400, "Missing required parameter 'article' when calling ArticlesApi->PrivateArticleCreate");

            var localVarPath = "/account/articles";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (article != null && article.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(article); // http body (model) parameter
            }
            else
            {
                localVarPostBody = article; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleCreate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<LocationWarnings>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (LocationWarnings) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(LocationWarnings)));
        }

        /// <summary>
        /// Delete article Delete an article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns></returns>
        public void PrivateArticleDelete (long? articleId)
        {
             PrivateArticleDeleteWithHttpInfo(articleId);
        }

        /// <summary>
        /// Delete article Delete an article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateArticleDeleteWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleDelete");

            var localVarPath = "/account/articles/{article_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Delete article Delete an article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateArticleDeleteAsync (long? articleId)
        {
             await PrivateArticleDeleteAsyncWithHttpInfo(articleId);

        }

        /// <summary>
        /// Delete article Delete an article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleDeleteAsyncWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleDelete");

            var localVarPath = "/account/articles/{article_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Article details View a private article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ArticleCompletePrivate</returns>
        public ArticleCompletePrivate PrivateArticleDetails (long? articleId)
        {
             ApiResponse<ArticleCompletePrivate> localVarResponse = PrivateArticleDetailsWithHttpInfo(articleId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Article details View a private article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of ArticleCompletePrivate</returns>
        public ApiResponse< ArticleCompletePrivate > PrivateArticleDetailsWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleDetails");

            var localVarPath = "/account/articles/{article_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleDetails", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<ArticleCompletePrivate>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (ArticleCompletePrivate) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(ArticleCompletePrivate)));
        }

        /// <summary>
        /// Article details View a private article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ArticleCompletePrivate</returns>
        public async System.Threading.Tasks.Task<ArticleCompletePrivate> PrivateArticleDetailsAsync (long? articleId)
        {
             ApiResponse<ArticleCompletePrivate> localVarResponse = await PrivateArticleDetailsAsyncWithHttpInfo(articleId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Article details View a private article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse (ArticleCompletePrivate)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<ArticleCompletePrivate>> PrivateArticleDetailsAsyncWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleDetails");

            var localVarPath = "/account/articles/{article_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleDetails", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<ArticleCompletePrivate>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (ArticleCompletePrivate) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(ArticleCompletePrivate)));
        }

        /// <summary>
        /// Delete Article Embargo Will lift the embargo for the specified article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns></returns>
        public void PrivateArticleEmbargoDelete (long? articleId)
        {
             PrivateArticleEmbargoDeleteWithHttpInfo(articleId);
        }

        /// <summary>
        /// Delete Article Embargo Will lift the embargo for the specified article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateArticleEmbargoDeleteWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleEmbargoDelete");

            var localVarPath = "/account/articles/{article_id}/embargo";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleEmbargoDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Delete Article Embargo Will lift the embargo for the specified article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateArticleEmbargoDeleteAsync (long? articleId)
        {
             await PrivateArticleEmbargoDeleteAsyncWithHttpInfo(articleId);

        }

        /// <summary>
        /// Delete Article Embargo Will lift the embargo for the specified article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleEmbargoDeleteAsyncWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleEmbargoDelete");

            var localVarPath = "/account/articles/{article_id}/embargo";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleEmbargoDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Article Embargo Details View a private article embargo details
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ArticleEmbargo</returns>
        public ArticleEmbargo PrivateArticleEmbargoDetails (long? articleId)
        {
             ApiResponse<ArticleEmbargo> localVarResponse = PrivateArticleEmbargoDetailsWithHttpInfo(articleId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Article Embargo Details View a private article embargo details
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of ArticleEmbargo</returns>
        public ApiResponse< ArticleEmbargo > PrivateArticleEmbargoDetailsWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleEmbargoDetails");

            var localVarPath = "/account/articles/{article_id}/embargo";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleEmbargoDetails", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<ArticleEmbargo>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (ArticleEmbargo) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(ArticleEmbargo)));
        }

        /// <summary>
        /// Article Embargo Details View a private article embargo details
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ArticleEmbargo</returns>
        public async System.Threading.Tasks.Task<ArticleEmbargo> PrivateArticleEmbargoDetailsAsync (long? articleId)
        {
             ApiResponse<ArticleEmbargo> localVarResponse = await PrivateArticleEmbargoDetailsAsyncWithHttpInfo(articleId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Article Embargo Details View a private article embargo details
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse (ArticleEmbargo)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<ArticleEmbargo>> PrivateArticleEmbargoDetailsAsyncWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleEmbargoDetails");

            var localVarPath = "/account/articles/{article_id}/embargo";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleEmbargoDetails", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<ArticleEmbargo>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (ArticleEmbargo) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(ArticleEmbargo)));
        }

        /// <summary>
        /// Update Article Embargo Note: setting an article under whole embargo does not imply that the article will be published when the embargo will expire. You must explicitly call the publish endpoint to enable this functionality.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="embargo">Embargo description</param>
        /// <returns></returns>
        public void PrivateArticleEmbargoUpdate (long? articleId, ArticleEmbargoUpdater embargo)
        {
             PrivateArticleEmbargoUpdateWithHttpInfo(articleId, embargo);
        }

        /// <summary>
        /// Update Article Embargo Note: setting an article under whole embargo does not imply that the article will be published when the embargo will expire. You must explicitly call the publish endpoint to enable this functionality.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="embargo">Embargo description</param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateArticleEmbargoUpdateWithHttpInfo (long? articleId, ArticleEmbargoUpdater embargo)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleEmbargoUpdate");
            // verify the required parameter 'embargo' is set
            if (embargo == null)
                throw new ApiException(400, "Missing required parameter 'embargo' when calling ArticlesApi->PrivateArticleEmbargoUpdate");

            var localVarPath = "/account/articles/{article_id}/embargo";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (embargo != null && embargo.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(embargo); // http body (model) parameter
            }
            else
            {
                localVarPostBody = embargo; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleEmbargoUpdate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Update Article Embargo Note: setting an article under whole embargo does not imply that the article will be published when the embargo will expire. You must explicitly call the publish endpoint to enable this functionality.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="embargo">Embargo description</param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateArticleEmbargoUpdateAsync (long? articleId, ArticleEmbargoUpdater embargo)
        {
             await PrivateArticleEmbargoUpdateAsyncWithHttpInfo(articleId, embargo);

        }

        /// <summary>
        /// Update Article Embargo Note: setting an article under whole embargo does not imply that the article will be published when the embargo will expire. You must explicitly call the publish endpoint to enable this functionality.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="embargo">Embargo description</param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleEmbargoUpdateAsyncWithHttpInfo (long? articleId, ArticleEmbargoUpdater embargo)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleEmbargoUpdate");
            // verify the required parameter 'embargo' is set
            if (embargo == null)
                throw new ApiException(400, "Missing required parameter 'embargo' when calling ArticlesApi->PrivateArticleEmbargoUpdate");

            var localVarPath = "/account/articles/{article_id}/embargo";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (embargo != null && embargo.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(embargo); // http body (model) parameter
            }
            else
            {
                localVarPostBody = embargo; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleEmbargoUpdate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Single File View details of file for specified article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns>PrivateFile</returns>
        public PrivateFile PrivateArticleFile (long? articleId, long? fileId)
        {
             ApiResponse<PrivateFile> localVarResponse = PrivateArticleFileWithHttpInfo(articleId, fileId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Single File View details of file for specified article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns>ApiResponse of PrivateFile</returns>
        public ApiResponse< PrivateFile > PrivateArticleFileWithHttpInfo (long? articleId, long? fileId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleFile");
            // verify the required parameter 'fileId' is set
            if (fileId == null)
                throw new ApiException(400, "Missing required parameter 'fileId' when calling ArticlesApi->PrivateArticleFile");

            var localVarPath = "/account/articles/{article_id}/files/{file_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (fileId != null) localVarPathParams.Add("file_id", this.Configuration.ApiClient.ParameterToString(fileId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleFile", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PrivateFile>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PrivateFile) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(PrivateFile)));
        }

        /// <summary>
        /// Single File View details of file for specified article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns>Task of PrivateFile</returns>
        public async System.Threading.Tasks.Task<PrivateFile> PrivateArticleFileAsync (long? articleId, long? fileId)
        {
             ApiResponse<PrivateFile> localVarResponse = await PrivateArticleFileAsyncWithHttpInfo(articleId, fileId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Single File View details of file for specified article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns>Task of ApiResponse (PrivateFile)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PrivateFile>> PrivateArticleFileAsyncWithHttpInfo (long? articleId, long? fileId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleFile");
            // verify the required parameter 'fileId' is set
            if (fileId == null)
                throw new ApiException(400, "Missing required parameter 'fileId' when calling ArticlesApi->PrivateArticleFile");

            var localVarPath = "/account/articles/{article_id}/files/{file_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (fileId != null) localVarPathParams.Add("file_id", this.Configuration.ApiClient.ParameterToString(fileId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleFile", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PrivateFile>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PrivateFile) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(PrivateFile)));
        }

        /// <summary>
        /// File Delete Complete file upload
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns></returns>
        public void PrivateArticleFileDelete (long? articleId, long? fileId)
        {
             PrivateArticleFileDeleteWithHttpInfo(articleId, fileId);
        }

        /// <summary>
        /// File Delete Complete file upload
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateArticleFileDeleteWithHttpInfo (long? articleId, long? fileId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleFileDelete");
            // verify the required parameter 'fileId' is set
            if (fileId == null)
                throw new ApiException(400, "Missing required parameter 'fileId' when calling ArticlesApi->PrivateArticleFileDelete");

            var localVarPath = "/account/articles/{article_id}/files/{file_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (fileId != null) localVarPathParams.Add("file_id", this.Configuration.ApiClient.ParameterToString(fileId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleFileDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// File Delete Complete file upload
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateArticleFileDeleteAsync (long? articleId, long? fileId)
        {
             await PrivateArticleFileDeleteAsyncWithHttpInfo(articleId, fileId);

        }

        /// <summary>
        /// File Delete Complete file upload
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleFileDeleteAsyncWithHttpInfo (long? articleId, long? fileId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleFileDelete");
            // verify the required parameter 'fileId' is set
            if (fileId == null)
                throw new ApiException(400, "Missing required parameter 'fileId' when calling ArticlesApi->PrivateArticleFileDelete");

            var localVarPath = "/account/articles/{article_id}/files/{file_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (fileId != null) localVarPathParams.Add("file_id", this.Configuration.ApiClient.ParameterToString(fileId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleFileDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// List article files List private files
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>List&lt;PrivateFile&gt;</returns>
        public List<PrivateFile> PrivateArticleFilesList (long? articleId)
        {
             ApiResponse<List<PrivateFile>> localVarResponse = PrivateArticleFilesListWithHttpInfo(articleId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// List article files List private files
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of List&lt;PrivateFile&gt;</returns>
        public ApiResponse< List<PrivateFile> > PrivateArticleFilesListWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleFilesList");

            var localVarPath = "/account/articles/{article_id}/files";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleFilesList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<PrivateFile>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<PrivateFile>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<PrivateFile>)));
        }

        /// <summary>
        /// List article files List private files
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of List&lt;PrivateFile&gt;</returns>
        public async System.Threading.Tasks.Task<List<PrivateFile>> PrivateArticleFilesListAsync (long? articleId)
        {
             ApiResponse<List<PrivateFile>> localVarResponse = await PrivateArticleFilesListAsyncWithHttpInfo(articleId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// List article files List private files
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse (List&lt;PrivateFile&gt;)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<List<PrivateFile>>> PrivateArticleFilesListAsyncWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleFilesList");

            var localVarPath = "/account/articles/{article_id}/files";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleFilesList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<PrivateFile>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<PrivateFile>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<PrivateFile>)));
        }

        /// <summary>
        /// List private links List private links
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>List&lt;PrivateLink&gt;</returns>
        public List<PrivateLink> PrivateArticlePrivateLink (long? articleId)
        {
             ApiResponse<List<PrivateLink>> localVarResponse = PrivateArticlePrivateLinkWithHttpInfo(articleId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// List private links List private links
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of List&lt;PrivateLink&gt;</returns>
        public ApiResponse< List<PrivateLink> > PrivateArticlePrivateLinkWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticlePrivateLink");

            var localVarPath = "/account/articles/{article_id}/private_links";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticlePrivateLink", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<PrivateLink>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<PrivateLink>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<PrivateLink>)));
        }

        /// <summary>
        /// List private links List private links
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of List&lt;PrivateLink&gt;</returns>
        public async System.Threading.Tasks.Task<List<PrivateLink>> PrivateArticlePrivateLinkAsync (long? articleId)
        {
             ApiResponse<List<PrivateLink>> localVarResponse = await PrivateArticlePrivateLinkAsyncWithHttpInfo(articleId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// List private links List private links
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse (List&lt;PrivateLink&gt;)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<List<PrivateLink>>> PrivateArticlePrivateLinkAsyncWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticlePrivateLink");

            var localVarPath = "/account/articles/{article_id}/private_links";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticlePrivateLink", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<PrivateLink>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<PrivateLink>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<PrivateLink>)));
        }

        /// <summary>
        /// Create private link Create new private link for this article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>PrivateLinkResponse</returns>
        public PrivateLinkResponse PrivateArticlePrivateLinkCreate (long? articleId, PrivateLinkCreator privateLink = null)
        {
             ApiResponse<PrivateLinkResponse> localVarResponse = PrivateArticlePrivateLinkCreateWithHttpInfo(articleId, privateLink);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Create private link Create new private link for this article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>ApiResponse of PrivateLinkResponse</returns>
        public ApiResponse< PrivateLinkResponse > PrivateArticlePrivateLinkCreateWithHttpInfo (long? articleId, PrivateLinkCreator privateLink = null)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticlePrivateLinkCreate");

            var localVarPath = "/account/articles/{article_id}/private_links";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (privateLink != null && privateLink.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(privateLink); // http body (model) parameter
            }
            else
            {
                localVarPostBody = privateLink; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticlePrivateLinkCreate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PrivateLinkResponse>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PrivateLinkResponse) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(PrivateLinkResponse)));
        }

        /// <summary>
        /// Create private link Create new private link for this article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>Task of PrivateLinkResponse</returns>
        public async System.Threading.Tasks.Task<PrivateLinkResponse> PrivateArticlePrivateLinkCreateAsync (long? articleId, PrivateLinkCreator privateLink = null)
        {
             ApiResponse<PrivateLinkResponse> localVarResponse = await PrivateArticlePrivateLinkCreateAsyncWithHttpInfo(articleId, privateLink);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Create private link Create new private link for this article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>Task of ApiResponse (PrivateLinkResponse)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PrivateLinkResponse>> PrivateArticlePrivateLinkCreateAsyncWithHttpInfo (long? articleId, PrivateLinkCreator privateLink = null)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticlePrivateLinkCreate");

            var localVarPath = "/account/articles/{article_id}/private_links";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (privateLink != null && privateLink.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(privateLink); // http body (model) parameter
            }
            else
            {
                localVarPostBody = privateLink; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticlePrivateLinkCreate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PrivateLinkResponse>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PrivateLinkResponse) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(PrivateLinkResponse)));
        }

        /// <summary>
        /// Disable private link Disable/delete private link for this article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <returns></returns>
        public void PrivateArticlePrivateLinkDelete (long? articleId, string linkId)
        {
             PrivateArticlePrivateLinkDeleteWithHttpInfo(articleId, linkId);
        }

        /// <summary>
        /// Disable private link Disable/delete private link for this article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateArticlePrivateLinkDeleteWithHttpInfo (long? articleId, string linkId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticlePrivateLinkDelete");
            // verify the required parameter 'linkId' is set
            if (linkId == null)
                throw new ApiException(400, "Missing required parameter 'linkId' when calling ArticlesApi->PrivateArticlePrivateLinkDelete");

            var localVarPath = "/account/articles/{article_id}/private_links/{link_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (linkId != null) localVarPathParams.Add("link_id", this.Configuration.ApiClient.ParameterToString(linkId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticlePrivateLinkDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Disable private link Disable/delete private link for this article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateArticlePrivateLinkDeleteAsync (long? articleId, string linkId)
        {
             await PrivateArticlePrivateLinkDeleteAsyncWithHttpInfo(articleId, linkId);

        }

        /// <summary>
        /// Disable private link Disable/delete private link for this article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticlePrivateLinkDeleteAsyncWithHttpInfo (long? articleId, string linkId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticlePrivateLinkDelete");
            // verify the required parameter 'linkId' is set
            if (linkId == null)
                throw new ApiException(400, "Missing required parameter 'linkId' when calling ArticlesApi->PrivateArticlePrivateLinkDelete");

            var localVarPath = "/account/articles/{article_id}/private_links/{link_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (linkId != null) localVarPathParams.Add("link_id", this.Configuration.ApiClient.ParameterToString(linkId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticlePrivateLinkDelete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Update private link Update existing private link for this article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns></returns>
        public void PrivateArticlePrivateLinkUpdate (long? articleId, string linkId, PrivateLinkCreator privateLink = null)
        {
             PrivateArticlePrivateLinkUpdateWithHttpInfo(articleId, linkId, privateLink);
        }

        /// <summary>
        /// Update private link Update existing private link for this article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateArticlePrivateLinkUpdateWithHttpInfo (long? articleId, string linkId, PrivateLinkCreator privateLink = null)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticlePrivateLinkUpdate");
            // verify the required parameter 'linkId' is set
            if (linkId == null)
                throw new ApiException(400, "Missing required parameter 'linkId' when calling ArticlesApi->PrivateArticlePrivateLinkUpdate");

            var localVarPath = "/account/articles/{article_id}/private_links/{link_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (linkId != null) localVarPathParams.Add("link_id", this.Configuration.ApiClient.ParameterToString(linkId)); // path parameter
            if (privateLink != null && privateLink.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(privateLink); // http body (model) parameter
            }
            else
            {
                localVarPostBody = privateLink; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticlePrivateLinkUpdate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Update private link Update existing private link for this article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateArticlePrivateLinkUpdateAsync (long? articleId, string linkId, PrivateLinkCreator privateLink = null)
        {
             await PrivateArticlePrivateLinkUpdateAsyncWithHttpInfo(articleId, linkId, privateLink);

        }

        /// <summary>
        /// Update private link Update existing private link for this article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="linkId">Private link token</param>
        /// <param name="privateLink"> (optional)</param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticlePrivateLinkUpdateAsyncWithHttpInfo (long? articleId, string linkId, PrivateLinkCreator privateLink = null)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticlePrivateLinkUpdate");
            // verify the required parameter 'linkId' is set
            if (linkId == null)
                throw new ApiException(400, "Missing required parameter 'linkId' when calling ArticlesApi->PrivateArticlePrivateLinkUpdate");

            var localVarPath = "/account/articles/{article_id}/private_links/{link_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (linkId != null) localVarPathParams.Add("link_id", this.Configuration.ApiClient.ParameterToString(linkId)); // path parameter
            if (privateLink != null && privateLink.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(privateLink); // http body (model) parameter
            }
            else
            {
                localVarPostBody = privateLink; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticlePrivateLinkUpdate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Private Article Publish - If the whole article is under embargo, it will not be published immediately, but when the embargo expires or is lifted. - When an article is published, a new public version will be generated. Any further updates to the article will affect the private article data. In order to make these changes publicly visible, an explicit publish operation is needed.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Location</returns>
        public Location PrivateArticlePublish (long? articleId)
        {
             ApiResponse<Location> localVarResponse = PrivateArticlePublishWithHttpInfo(articleId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Private Article Publish - If the whole article is under embargo, it will not be published immediately, but when the embargo expires or is lifted. - When an article is published, a new public version will be generated. Any further updates to the article will affect the private article data. In order to make these changes publicly visible, an explicit publish operation is needed.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of Location</returns>
        public ApiResponse< Location > PrivateArticlePublishWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticlePublish");

            var localVarPath = "/account/articles/{article_id}/publish";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticlePublish", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Location>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (Location) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(Location)));
        }

        /// <summary>
        /// Private Article Publish - If the whole article is under embargo, it will not be published immediately, but when the embargo expires or is lifted. - When an article is published, a new public version will be generated. Any further updates to the article will affect the private article data. In order to make these changes publicly visible, an explicit publish operation is needed.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of Location</returns>
        public async System.Threading.Tasks.Task<Location> PrivateArticlePublishAsync (long? articleId)
        {
             ApiResponse<Location> localVarResponse = await PrivateArticlePublishAsyncWithHttpInfo(articleId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Private Article Publish - If the whole article is under embargo, it will not be published immediately, but when the embargo expires or is lifted. - When an article is published, a new public version will be generated. Any further updates to the article will affect the private article data. In order to make these changes publicly visible, an explicit publish operation is needed.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse (Location)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Location>> PrivateArticlePublishAsyncWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticlePublish");

            var localVarPath = "/account/articles/{article_id}/publish";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticlePublish", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Location>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (Location) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(Location)));
        }

        /// <summary>
        /// Private Article Reserve DOI Reserve DOI for article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ArticleDOI</returns>
        public ArticleDOI PrivateArticleReserveDoi (long? articleId)
        {
             ApiResponse<ArticleDOI> localVarResponse = PrivateArticleReserveDoiWithHttpInfo(articleId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Private Article Reserve DOI Reserve DOI for article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of ArticleDOI</returns>
        public ApiResponse< ArticleDOI > PrivateArticleReserveDoiWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleReserveDoi");

            var localVarPath = "/account/articles/{article_id}/reserve_doi";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleReserveDoi", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<ArticleDOI>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (ArticleDOI) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(ArticleDOI)));
        }

        /// <summary>
        /// Private Article Reserve DOI Reserve DOI for article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ArticleDOI</returns>
        public async System.Threading.Tasks.Task<ArticleDOI> PrivateArticleReserveDoiAsync (long? articleId)
        {
             ApiResponse<ArticleDOI> localVarResponse = await PrivateArticleReserveDoiAsyncWithHttpInfo(articleId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Private Article Reserve DOI Reserve DOI for article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse (ArticleDOI)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<ArticleDOI>> PrivateArticleReserveDoiAsyncWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleReserveDoi");

            var localVarPath = "/account/articles/{article_id}/reserve_doi";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleReserveDoi", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<ArticleDOI>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (ArticleDOI) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(ArticleDOI)));
        }

        /// <summary>
        /// Private Article Reserve Handle Reserve Handle for article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ArticleHandle</returns>
        public ArticleHandle PrivateArticleReserveHandle (long? articleId)
        {
             ApiResponse<ArticleHandle> localVarResponse = PrivateArticleReserveHandleWithHttpInfo(articleId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Private Article Reserve Handle Reserve Handle for article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>ApiResponse of ArticleHandle</returns>
        public ApiResponse< ArticleHandle > PrivateArticleReserveHandleWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleReserveHandle");

            var localVarPath = "/account/articles/{article_id}/reserve_handle";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleReserveHandle", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<ArticleHandle>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (ArticleHandle) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(ArticleHandle)));
        }

        /// <summary>
        /// Private Article Reserve Handle Reserve Handle for article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ArticleHandle</returns>
        public async System.Threading.Tasks.Task<ArticleHandle> PrivateArticleReserveHandleAsync (long? articleId)
        {
             ApiResponse<ArticleHandle> localVarResponse = await PrivateArticleReserveHandleAsyncWithHttpInfo(articleId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Private Article Reserve Handle Reserve Handle for article
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <returns>Task of ApiResponse (ArticleHandle)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<ArticleHandle>> PrivateArticleReserveHandleAsyncWithHttpInfo (long? articleId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleReserveHandle");

            var localVarPath = "/account/articles/{article_id}/reserve_handle";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleReserveHandle", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<ArticleHandle>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (ArticleHandle) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(ArticleHandle)));
        }

        /// <summary>
        /// Private Article Resource Edit article resource data.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="resource">Resource data</param>
        /// <returns>Location</returns>
        public Location PrivateArticleResource (long? articleId, Resource resource)
        {
             ApiResponse<Location> localVarResponse = PrivateArticleResourceWithHttpInfo(articleId, resource);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Private Article Resource Edit article resource data.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="resource">Resource data</param>
        /// <returns>ApiResponse of Location</returns>
        public ApiResponse< Location > PrivateArticleResourceWithHttpInfo (long? articleId, Resource resource)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleResource");
            // verify the required parameter 'resource' is set
            if (resource == null)
                throw new ApiException(400, "Missing required parameter 'resource' when calling ArticlesApi->PrivateArticleResource");

            var localVarPath = "/account/articles/{article_id}/resource";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (resource != null && resource.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(resource); // http body (model) parameter
            }
            else
            {
                localVarPostBody = resource; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleResource", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Location>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (Location) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(Location)));
        }

        /// <summary>
        /// Private Article Resource Edit article resource data.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="resource">Resource data</param>
        /// <returns>Task of Location</returns>
        public async System.Threading.Tasks.Task<Location> PrivateArticleResourceAsync (long? articleId, Resource resource)
        {
             ApiResponse<Location> localVarResponse = await PrivateArticleResourceAsyncWithHttpInfo(articleId, resource);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Private Article Resource Edit article resource data.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="resource">Resource data</param>
        /// <returns>Task of ApiResponse (Location)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Location>> PrivateArticleResourceAsyncWithHttpInfo (long? articleId, Resource resource)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleResource");
            // verify the required parameter 'resource' is set
            if (resource == null)
                throw new ApiException(400, "Missing required parameter 'resource' when calling ArticlesApi->PrivateArticleResource");

            var localVarPath = "/account/articles/{article_id}/resource";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (resource != null && resource.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(resource); // http body (model) parameter
            }
            else
            {
                localVarPostBody = resource; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleResource", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Location>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (Location) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(Location)));
        }

        /// <summary>
        /// Update article Updating an article by passing body parameters; request can also be made with the PATCH method.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="article">Article description</param>
        /// <returns>LocationWarningsUpdate</returns>
        public LocationWarningsUpdate PrivateArticleUpdate (long? articleId, ArticleUpdate article)
        {
             ApiResponse<LocationWarningsUpdate> localVarResponse = PrivateArticleUpdateWithHttpInfo(articleId, article);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Update article Updating an article by passing body parameters; request can also be made with the PATCH method.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="article">Article description</param>
        /// <returns>ApiResponse of LocationWarningsUpdate</returns>
        public ApiResponse< LocationWarningsUpdate > PrivateArticleUpdateWithHttpInfo (long? articleId, ArticleUpdate article)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleUpdate");
            // verify the required parameter 'article' is set
            if (article == null)
                throw new ApiException(400, "Missing required parameter 'article' when calling ArticlesApi->PrivateArticleUpdate");

            var localVarPath = "/account/articles/{article_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (article != null && article.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(article); // http body (model) parameter
            }
            else
            {
                localVarPostBody = article; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleUpdate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<LocationWarningsUpdate>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (LocationWarningsUpdate) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(LocationWarningsUpdate)));
        }

        /// <summary>
        /// Update article Updating an article by passing body parameters; request can also be made with the PATCH method.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="article">Article description</param>
        /// <returns>Task of LocationWarningsUpdate</returns>
        public async System.Threading.Tasks.Task<LocationWarningsUpdate> PrivateArticleUpdateAsync (long? articleId, ArticleUpdate article)
        {
             ApiResponse<LocationWarningsUpdate> localVarResponse = await PrivateArticleUpdateAsyncWithHttpInfo(articleId, article);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Update article Updating an article by passing body parameters; request can also be made with the PATCH method.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="article">Article description</param>
        /// <returns>Task of ApiResponse (LocationWarningsUpdate)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<LocationWarningsUpdate>> PrivateArticleUpdateAsyncWithHttpInfo (long? articleId, ArticleUpdate article)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleUpdate");
            // verify the required parameter 'article' is set
            if (article == null)
                throw new ApiException(400, "Missing required parameter 'article' when calling ArticlesApi->PrivateArticleUpdate");

            var localVarPath = "/account/articles/{article_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (article != null && article.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(article); // http body (model) parameter
            }
            else
            {
                localVarPostBody = article; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleUpdate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<LocationWarningsUpdate>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (LocationWarningsUpdate) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(LocationWarningsUpdate)));
        }

        /// <summary>
        /// Complete Upload Complete file upload
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns></returns>
        public void PrivateArticleUploadComplete (long? articleId, long? fileId)
        {
             PrivateArticleUploadCompleteWithHttpInfo(articleId, fileId);
        }

        /// <summary>
        /// Complete Upload Complete file upload
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns>ApiResponse of Object(void)</returns>
        public ApiResponse<Object> PrivateArticleUploadCompleteWithHttpInfo (long? articleId, long? fileId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleUploadComplete");
            // verify the required parameter 'fileId' is set
            if (fileId == null)
                throw new ApiException(400, "Missing required parameter 'fileId' when calling ArticlesApi->PrivateArticleUploadComplete");

            var localVarPath = "/account/articles/{article_id}/files/{file_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (fileId != null) localVarPathParams.Add("file_id", this.Configuration.ApiClient.ParameterToString(fileId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleUploadComplete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Complete Upload Complete file upload
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns>Task of void</returns>
        public async System.Threading.Tasks.Task PrivateArticleUploadCompleteAsync (long? articleId, long? fileId)
        {
             await PrivateArticleUploadCompleteAsyncWithHttpInfo(articleId, fileId);

        }

        /// <summary>
        /// Complete Upload Complete file upload
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="fileId">File unique identifier</param>
        /// <returns>Task of ApiResponse</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Object>> PrivateArticleUploadCompleteAsyncWithHttpInfo (long? articleId, long? fileId)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleUploadComplete");
            // verify the required parameter 'fileId' is set
            if (fileId == null)
                throw new ApiException(400, "Missing required parameter 'fileId' when calling ArticlesApi->PrivateArticleUploadComplete");

            var localVarPath = "/account/articles/{article_id}/files/{file_id}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (fileId != null) localVarPathParams.Add("file_id", this.Configuration.ApiClient.ParameterToString(fileId)); // path parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleUploadComplete", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Object>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                null);
        }

        /// <summary>
        /// Initiate Upload Initiate a new file upload within the article. Either use the link property to point to an existing file that resides elsewhere and will not be uploaded to Figshare or use the other 3 parameters (md5, name, size).
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="_file"></param>
        /// <returns>Location</returns>
        public Location PrivateArticleUploadInitiate (long? articleId, FileCreator _file)
        {
             ApiResponse<Location> localVarResponse = PrivateArticleUploadInitiateWithHttpInfo(articleId, _file);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Initiate Upload Initiate a new file upload within the article. Either use the link property to point to an existing file that resides elsewhere and will not be uploaded to Figshare or use the other 3 parameters (md5, name, size).
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="_file"></param>
        /// <returns>ApiResponse of Location</returns>
        public ApiResponse< Location > PrivateArticleUploadInitiateWithHttpInfo (long? articleId, FileCreator _file)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleUploadInitiate");
            // verify the required parameter '_file' is set
            if (_file == null)
                throw new ApiException(400, "Missing required parameter '_file' when calling ArticlesApi->PrivateArticleUploadInitiate");

            var localVarPath = "/account/articles/{article_id}/files";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (_file != null && _file.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(_file); // http body (model) parameter
            }
            else
            {
                localVarPostBody = _file; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleUploadInitiate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Location>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (Location) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(Location)));
        }

        /// <summary>
        /// Initiate Upload Initiate a new file upload within the article. Either use the link property to point to an existing file that resides elsewhere and will not be uploaded to Figshare or use the other 3 parameters (md5, name, size).
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="_file"></param>
        /// <returns>Task of Location</returns>
        public async System.Threading.Tasks.Task<Location> PrivateArticleUploadInitiateAsync (long? articleId, FileCreator _file)
        {
             ApiResponse<Location> localVarResponse = await PrivateArticleUploadInitiateAsyncWithHttpInfo(articleId, _file);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Initiate Upload Initiate a new file upload within the article. Either use the link property to point to an existing file that resides elsewhere and will not be uploaded to Figshare or use the other 3 parameters (md5, name, size).
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="articleId">Article unique identifier</param>
        /// <param name="_file"></param>
        /// <returns>Task of ApiResponse (Location)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<Location>> PrivateArticleUploadInitiateAsyncWithHttpInfo (long? articleId, FileCreator _file)
        {
            // verify the required parameter 'articleId' is set
            if (articleId == null)
                throw new ApiException(400, "Missing required parameter 'articleId' when calling ArticlesApi->PrivateArticleUploadInitiate");
            // verify the required parameter '_file' is set
            if (_file == null)
                throw new ApiException(400, "Missing required parameter '_file' when calling ArticlesApi->PrivateArticleUploadInitiate");

            var localVarPath = "/account/articles/{article_id}/files";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (articleId != null) localVarPathParams.Add("article_id", this.Configuration.ApiClient.ParameterToString(articleId)); // path parameter
            if (_file != null && _file.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(_file); // http body (model) parameter
            }
            else
            {
                localVarPostBody = _file; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticleUploadInitiate", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<Location>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (Location) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(Location)));
        }

        /// <summary>
        /// Private Articles Get Own Articles
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>List&lt;Article&gt;</returns>
        public List<Article> PrivateArticlesList (long? page = null, long? pageSize = null, long? limit = null, long? offset = null)
        {
             ApiResponse<List<Article>> localVarResponse = PrivateArticlesListWithHttpInfo(page, pageSize, limit, offset);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Private Articles Get Own Articles
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>ApiResponse of List&lt;Article&gt;</returns>
        public ApiResponse< List<Article> > PrivateArticlesListWithHttpInfo (long? page = null, long? pageSize = null, long? limit = null, long? offset = null)
        {

            var localVarPath = "/account/articles";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (page != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page", page)); // query parameter
            if (pageSize != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page_size", pageSize)); // query parameter
            if (limit != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "limit", limit)); // query parameter
            if (offset != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "offset", offset)); // query parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticlesList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Article>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Article>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Article>)));
        }

        /// <summary>
        /// Private Articles Get Own Articles
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>Task of List&lt;Article&gt;</returns>
        public async System.Threading.Tasks.Task<List<Article>> PrivateArticlesListAsync (long? page = null, long? pageSize = null, long? limit = null, long? offset = null)
        {
             ApiResponse<List<Article>> localVarResponse = await PrivateArticlesListAsyncWithHttpInfo(page, pageSize, limit, offset);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Private Articles Get Own Articles
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="page">Page number. Used for pagination with page_size (optional)</param>
        /// <param name="pageSize">The number of results included on a page. Used for pagination with page (optional, default to 10)</param>
        /// <param name="limit">Number of results included on a page. Used for pagination with query (optional)</param>
        /// <param name="offset">Where to start the listing(the offset of the first result). Used for pagination with limit (optional)</param>
        /// <returns>Task of ApiResponse (List&lt;Article&gt;)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<List<Article>>> PrivateArticlesListAsyncWithHttpInfo (long? page = null, long? pageSize = null, long? limit = null, long? offset = null)
        {

            var localVarPath = "/account/articles";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (page != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page", page)); // query parameter
            if (pageSize != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "page_size", pageSize)); // query parameter
            if (limit != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "limit", limit)); // query parameter
            if (offset != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "offset", offset)); // query parameter

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticlesList", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<Article>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<Article>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<Article>)));
        }

        /// <summary>
        /// Private Articles search Returns a list of private articles filtered by the search parameters
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="search">Search Parameters</param>
        /// <returns>List&lt;ArticleWithProject&gt;</returns>
        public List<ArticleWithProject> PrivateArticlesSearch (PrivateArticleSearch search)
        {
             ApiResponse<List<ArticleWithProject>> localVarResponse = PrivateArticlesSearchWithHttpInfo(search);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Private Articles search Returns a list of private articles filtered by the search parameters
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="search">Search Parameters</param>
        /// <returns>ApiResponse of List&lt;ArticleWithProject&gt;</returns>
        public ApiResponse< List<ArticleWithProject> > PrivateArticlesSearchWithHttpInfo (PrivateArticleSearch search)
        {
            // verify the required parameter 'search' is set
            if (search == null)
                throw new ApiException(400, "Missing required parameter 'search' when calling ArticlesApi->PrivateArticlesSearch");

            var localVarPath = "/account/articles/search";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (search != null && search.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(search); // http body (model) parameter
            }
            else
            {
                localVarPostBody = search; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticlesSearch", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<ArticleWithProject>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<ArticleWithProject>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<ArticleWithProject>)));
        }

        /// <summary>
        /// Private Articles search Returns a list of private articles filtered by the search parameters
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="search">Search Parameters</param>
        /// <returns>Task of List&lt;ArticleWithProject&gt;</returns>
        public async System.Threading.Tasks.Task<List<ArticleWithProject>> PrivateArticlesSearchAsync (PrivateArticleSearch search)
        {
             ApiResponse<List<ArticleWithProject>> localVarResponse = await PrivateArticlesSearchAsyncWithHttpInfo(search);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Private Articles search Returns a list of private articles filtered by the search parameters
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="search">Search Parameters</param>
        /// <returns>Task of ApiResponse (List&lt;ArticleWithProject&gt;)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<List<ArticleWithProject>>> PrivateArticlesSearchAsyncWithHttpInfo (PrivateArticleSearch search)
        {
            // verify the required parameter 'search' is set
            if (search == null)
                throw new ApiException(400, "Missing required parameter 'search' when calling ArticlesApi->PrivateArticlesSearch");

            var localVarPath = "/account/articles/search";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (search != null && search.GetType() != typeof(byte[]))
            {
                localVarPostBody = this.Configuration.ApiClient.Serialize(search); // http body (model) parameter
            }
            else
            {
                localVarPostBody = search; // byte array
            }

            // authentication (OAuth2) required
            // oauth required
            if (!String.IsNullOrEmpty(this.Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + this.Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PrivateArticlesSearch", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<List<ArticleWithProject>>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (List<ArticleWithProject>) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(List<ArticleWithProject>)));
        }

    }
}
